package org.scalatest.inspectors.all

import org.scalatest._
import org.scalatest.matchers.{BePropertyMatcher, BePropertyMatchResult, HavePropertyMatcher, HavePropertyMatchResult}
import collection.GenTraversable
import collection.GenMap
class InspectorShorthandsForAllFailedSpec0 extends Spec with Matchers with SharedHelpers {
  class EmptyBePropertyMatcher extends BePropertyMatcher[String] {
    def apply(left: String) = BePropertyMatchResult(left.isEmpty, "empty")
  }
  class StringLengthMatcher(expectedValue: Int) extends HavePropertyMatcher[String, Int] {
    def apply(value: String) = {
      new HavePropertyMatchResult(value.length == expectedValue, "length", expectedValue, value.length)
    }
  }
  val empty = new EmptyBePropertyMatcher()
  def plength(expectedValue: Int) = new StringLengthMatcher(expectedValue)
  val theInstance = "2"
  def arrayToString(xs: GenTraversable[_]): String = xs.toString
  def checkErrorAndCause(e: exceptions.TestFailedException, assertLineNumber: Int, fileName: String, errorMessage: String, causeErrorMessage: String) {
    assert(e.failedCodeFileName == Some(fileName), e.failedCodeFileName + " did not equal " + Some(fileName))
    assert(e.failedCodeLineNumber == Some(assertLineNumber), e.failedCodeLineNumber + " did not equal " + Some(assertLineNumber))
    assert(e.message == Some(errorMessage), e.message + " did not equal " + Some(
  errorMessage))
    e.getCause match {
      case tfe: exceptions.TestFailedException =>
        assert(tfe.failedCodeFileName == Some(fileName), tfe.failedCodeFileName + " did not equal " + Some(fileName))
        assert(tfe.failedCodeLineNumber == Some(assertLineNumber), tfe.failedCodeLineNumber + " did not equal " + Some(assertLineNumber))
        assert(tfe.message == Some(causeErrorMessage), tfe.message + " did not equal " + Some(causeErrorMessage))
        assert(tfe.getCause == null, tfe.getCause + " was not null")
      case other => fail("Expected cause to be TestFailedException, but got: " + other)
    }
  }
  def checkError(e: exceptions.TestFailedException, assertLineNumber: Int, fileName: String, errorMessage: String) {
    assert(e.failedCodeFileName == Some(fileName), e.failedCodeFileName + " did not equal " + Some(fileName))
    assert(e.failedCodeLineNumber == Some(assertLineNumber), e.failedCodeLineNumber + " did not equal " + Some(assertLineNumber))
    assert(e.message == Some(errorMessage), e.message + " did not equal " + Some(
  errorMessage))
  }
  def equal[T](left: T, right: T): Boolean = left == right
  def javaArrayList[T](valueList: List[T]): java.util.ArrayList[T] = {
    val col = new java.util.ArrayList[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaHashSet[T](valueList: List[T]): java.util.HashSet[T] = {
    val col = new java.util.HashSet[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaLinkedList[T](valueList: List[T]): java.util.LinkedList[T] = {
    val col = new java.util.LinkedList[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaStack[T](valueList: List[T]): java.util.Stack[T] = {
    val col = new java.util.Stack[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaTreeSet[T](valueList: List[T]): java.util.TreeSet[T] = {
    val col = new java.util.TreeSet[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaVector[T](valueList: List[T]): java.util.Vector[T] = {
    val col = new java.util.Vector[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaArrayBlockingQueue[T](valueList: List[T], size: Int): java.util.concurrent.ArrayBlockingQueue[T] = {
    val col = new java.util.concurrent.ArrayBlockingQueue[T](size)
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaArrayDeque[T](valueList: List[T]): java.util.ArrayDeque[T] = {
    val col = new java.util.ArrayDeque[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaConcurrentLinkedQueue[T](valueList: List[T]): java.util.concurrent.ConcurrentLinkedQueue[T] = {
    val col = new java.util.concurrent.ConcurrentLinkedQueue[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaConcurrentSkipListSet[T](valueList: List[T]): java.util.concurrent.ConcurrentSkipListSet[T] = {
    val col = new java.util.concurrent.ConcurrentSkipListSet[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaCopyOnWriteArrayList[T](valueList: List[T]): java.util.concurrent.CopyOnWriteArrayList[T] = {
    val col = new java.util.concurrent.CopyOnWriteArrayList[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaCopyOnWriteArraySet[T](valueList: List[T]): java.util.concurrent.CopyOnWriteArraySet[T] = {
    val col = new java.util.concurrent.CopyOnWriteArraySet[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaLinkedBlockingDeque[T](valueList: List[T]): java.util.concurrent.LinkedBlockingDeque[T] = {
    val col = new java.util.concurrent.LinkedBlockingDeque[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaLinkedBlockingQueue[T](valueList: List[T]): java.util.concurrent.LinkedBlockingQueue[T] = {
    val col = new java.util.concurrent.LinkedBlockingQueue[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaLinkedHashSet[T](valueList: List[T]): java.util.LinkedHashSet[T] = {
    val col = new java.util.LinkedHashSet[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaPriorityBlockingQueue[T](valueList: List[T]): java.util.concurrent.PriorityBlockingQueue[T] = {
    val col = new java.util.concurrent.PriorityBlockingQueue[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaPriorityQueue[T](valueList: List[T]): java.util.PriorityQueue[T] = {
    val col = new java.util.PriorityQueue[T]()
    for (value <- valueList)
      col.add(value)
    col
  }
  def javaHashMap[K, V](valueMap: Map[K, V]): java.util.HashMap[K, V] = {
    val map = new java.util.HashMap[K, V]()
    for ((key, value) <- valueMap)
      map.put(key, value)
    map
  }
  def javaTreeMap[K, V](valueMap: Map[K, V]): java.util.TreeMap[K, V] = {
    val map = new java.util.TreeMap[K, V]()
    for ((key, value) <- valueMap)
      map.put(key, value)
    map
  }
  def javaHashtable[K, V](valueMap: Map[K, V]): java.util.Hashtable[K, V] = {
    val map = new java.util.Hashtable[K, V]()
    for ((key, value) <- valueMap)
      map.put(key, value)
    map
  }
  def javaConcurrentHashMap[K, V](valueMap: Map[K, V]): java.util.concurrent.ConcurrentHashMap[K, V] = {
    val map = new java.util.concurrent.ConcurrentHashMap[K, V]()
    for ((key, value) <- valueMap)
      map.put(key, value)
    map
  }
  def javaConcurrentSkipListMap[K, V](valueMap: Map[K, V]): java.util.concurrent.ConcurrentSkipListMap[K, V] = {
    val map = new java.util.concurrent.ConcurrentSkipListMap[K, V]()
    for ((key, value) <- valueMap)
      map.put(key, value)
    map
  }
  def javaLinkedHashMap[K, V](valueMap: Map[K, V]): java.util.LinkedHashMap[K, V] = {
    val map = new java.util.LinkedHashMap[K, V]()
    for ((key, value) <- valueMap)
      map.put(key, value)
    map
  }
  def javaWeakHashMap[K, V](valueMap: Map[K, V]): java.util.WeakHashMap[K, V] = {
    val map = new java.util.WeakHashMap[K, V]()
    for ((key, value) <- valueMap)
      map.put(key, value)
    map
  }
  def javaProperties(valueMap: Map[String, String]): java.util.Properties = {
    val map = new java.util.Properties()
    for ((key, value) <- valueMap)
      map.put(key, value)
    map
  }
  def `Set(1, 2, 3) should throw TestFailedException with correct stack depth and message when at least one element failed` {
    val xs = Set(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not equal 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " equaled 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " equaled 2")
  }
  def `Set(1, 2, 3) should throw TestFailedException with correct stack depth and message when more than one element failed` {
    val xs = Set(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be < 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThanEqual(xs, 2)) + ", " + getFirstMoreThanEqual(xs, 2) + " was not less than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThanEqual(xs, 2) + " was not less than 2")
  }
  def `Set(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should equal' failed` {
    val xs = Set(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should equal (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[Int](xs, 2)) + ", " + getFirstNotEqual[Int](xs, 2) + " did not equal 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstNotEqual[Int](xs, 2) + " did not equal 2")
  }
  def `Set(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not equal' failed` {
    val xs = Set(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not equal 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " equaled 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " equaled 2")
  }
  def `Set(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should be' failed` {
    val xs = Set(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[Int](xs, 2)) + ", " + getFirstNotEqual[Int](xs, 2) + " was not equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstNotEqual[Int](xs, 2) + " was not equal to 2")
  }
  def `Set(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not be' failed` {
    val xs = Set(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " was equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " was equal to 2")
  }
  def `Set(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should be less than comparison' failed` {
    val xs = Set(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be < 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThanEqual(xs, 2)) + ", " + getFirstMoreThanEqual(xs, 2) + " was not less than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThanEqual(xs, 2) + " was not less than 2")
  }
  def `Set(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not be less than comparison' failed` {
    val xs = Set(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be < (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThan(xs, 2)) + ", " + getFirstLessThan(xs, 2) + " was less than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThan(xs, 2) + " was less than 2")
  }
  def `Set(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should be less than or equal comparison' failed` {
    val xs = Set(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be <= 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThan(xs, 2)) + ", " + getFirstMoreThan(xs, 2) + " was not less than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThan(xs, 2) + " was not less than or equal to 2")
  }
  def `Set(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not be less than or equal comparison' failed` {
    val xs = Set(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be <= (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThanEqual(xs, 2)) + ", " + getFirstLessThanEqual(xs, 2) + " was less than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThanEqual(xs, 2) + " was less than or equal to 2")
  }
  def `Set(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should be greater than comparison' failed` {
    val xs = Set(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be > 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThanEqual(xs, 2)) + ", " + getFirstLessThanEqual(xs, 2) + " was not greater than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThanEqual(xs, 2) + " was not greater than 2")
  }
  def `Set(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not be greater than comparison' failed` {
    val xs = Set(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be > (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThan(xs, 2)) + ", " + getFirstMoreThan(xs, 2) + " was greater than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThan(xs, 2) + " was greater than 2")
  }
  def `Set(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should be greater than or equal comparison' failed` {
    val xs = Set(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be >= 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThan(xs, 2)) + ", " + getFirstLessThan(xs, 2) + " was not greater than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThan(xs, 2) + " was not greater than or equal to 2")
  }
  def `Set(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not be greater than or equal comparison' failed` {
    val xs = Set(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be >= (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThanEqual(xs, 2)) + ", " + getFirstMoreThanEqual(xs, 2) + " was greater than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThanEqual(xs, 2) + " was greater than or equal to 2")
  }
  def `Set(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should be ===' failed` {
    val xs = Set(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be === 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[Int](xs, 2)) + ", " + getFirstNotEqual[Int](xs, 2) + " was not equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstNotEqual[Int](xs, 2) + " was not equal to 2")
  }
  def `Set(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not be ===' failed` {
    val xs = Set(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be === (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " was equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " was equal to 2")
  }
  def `List(1, 2, 3) should throw TestFailedException with correct stack depth and message when at least one element failed` {
    val xs = List(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not equal 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " equaled 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " equaled 2")
  }
  def `List(1, 2, 3) should throw TestFailedException with correct stack depth and message when more than one element failed` {
    val xs = List(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be < 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThanEqual(xs, 2)) + ", " + getFirstMoreThanEqual(xs, 2) + " was not less than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThanEqual(xs, 2) + " was not less than 2")
  }
  def `List(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should equal' failed` {
    val xs = List(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should equal (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[Int](xs, 2)) + ", " + getFirstNotEqual[Int](xs, 2) + " did not equal 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstNotEqual[Int](xs, 2) + " did not equal 2")
  }
  def `List(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not equal' failed` {
    val xs = List(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not equal 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " equaled 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " equaled 2")
  }
  def `List(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should be' failed` {
    val xs = List(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[Int](xs, 2)) + ", " + getFirstNotEqual[Int](xs, 2) + " was not equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstNotEqual[Int](xs, 2) + " was not equal to 2")
  }
  def `List(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not be' failed` {
    val xs = List(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " was equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " was equal to 2")
  }
  def `List(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should be less than comparison' failed` {
    val xs = List(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be < 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThanEqual(xs, 2)) + ", " + getFirstMoreThanEqual(xs, 2) + " was not less than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThanEqual(xs, 2) + " was not less than 2")
  }
  def `List(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not be less than comparison' failed` {
    val xs = List(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be < (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThan(xs, 2)) + ", " + getFirstLessThan(xs, 2) + " was less than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThan(xs, 2) + " was less than 2")
  }
  def `List(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should be less than or equal comparison' failed` {
    val xs = List(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be <= 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThan(xs, 2)) + ", " + getFirstMoreThan(xs, 2) + " was not less than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThan(xs, 2) + " was not less than or equal to 2")
  }
  def `List(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not be less than or equal comparison' failed` {
    val xs = List(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be <= (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThanEqual(xs, 2)) + ", " + getFirstLessThanEqual(xs, 2) + " was less than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThanEqual(xs, 2) + " was less than or equal to 2")
  }
  def `List(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should be greater than comparison' failed` {
    val xs = List(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be > 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThanEqual(xs, 2)) + ", " + getFirstLessThanEqual(xs, 2) + " was not greater than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThanEqual(xs, 2) + " was not greater than 2")
  }
  def `List(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not be greater than comparison' failed` {
    val xs = List(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be > (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThan(xs, 2)) + ", " + getFirstMoreThan(xs, 2) + " was greater than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThan(xs, 2) + " was greater than 2")
  }
  def `List(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should be greater than or equal comparison' failed` {
    val xs = List(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be >= 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThan(xs, 2)) + ", " + getFirstLessThan(xs, 2) + " was not greater than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThan(xs, 2) + " was not greater than or equal to 2")
  }
  def `List(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not be greater than or equal comparison' failed` {
    val xs = List(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be >= (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThanEqual(xs, 2)) + ", " + getFirstMoreThanEqual(xs, 2) + " was greater than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThanEqual(xs, 2) + " was greater than or equal to 2")
  }
  def `List(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should be ===' failed` {
    val xs = List(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be === 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[Int](xs, 2)) + ", " + getFirstNotEqual[Int](xs, 2) + " was not equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstNotEqual[Int](xs, 2) + " was not equal to 2")
  }
  def `List(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not be ===' failed` {
    val xs = List(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be === (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " was equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " was equal to 2")
  }
  def `Seq(1, 2, 3) should throw TestFailedException with correct stack depth and message when at least one element failed` {
    val xs = Seq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not equal 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " equaled 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " equaled 2")
  }
  def `Seq(1, 2, 3) should throw TestFailedException with correct stack depth and message when more than one element failed` {
    val xs = Seq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be < 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThanEqual(xs, 2)) + ", " + getFirstMoreThanEqual(xs, 2) + " was not less than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThanEqual(xs, 2) + " was not less than 2")
  }
  def `Seq(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should equal' failed` {
    val xs = Seq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should equal (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[Int](xs, 2)) + ", " + getFirstNotEqual[Int](xs, 2) + " did not equal 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstNotEqual[Int](xs, 2) + " did not equal 2")
  }
  def `Seq(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not equal' failed` {
    val xs = Seq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not equal 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " equaled 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " equaled 2")
  }
  def `Seq(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should be' failed` {
    val xs = Seq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[Int](xs, 2)) + ", " + getFirstNotEqual[Int](xs, 2) + " was not equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstNotEqual[Int](xs, 2) + " was not equal to 2")
  }
  def `Seq(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not be' failed` {
    val xs = Seq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " was equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " was equal to 2")
  }
  def `Seq(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should be less than comparison' failed` {
    val xs = Seq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be < 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThanEqual(xs, 2)) + ", " + getFirstMoreThanEqual(xs, 2) + " was not less than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThanEqual(xs, 2) + " was not less than 2")
  }
  def `Seq(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not be less than comparison' failed` {
    val xs = Seq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be < (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThan(xs, 2)) + ", " + getFirstLessThan(xs, 2) + " was less than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThan(xs, 2) + " was less than 2")
  }
  def `Seq(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should be less than or equal comparison' failed` {
    val xs = Seq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be <= 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThan(xs, 2)) + ", " + getFirstMoreThan(xs, 2) + " was not less than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThan(xs, 2) + " was not less than or equal to 2")
  }
  def `Seq(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not be less than or equal comparison' failed` {
    val xs = Seq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be <= (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThanEqual(xs, 2)) + ", " + getFirstLessThanEqual(xs, 2) + " was less than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThanEqual(xs, 2) + " was less than or equal to 2")
  }
  def `Seq(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should be greater than comparison' failed` {
    val xs = Seq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be > 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThanEqual(xs, 2)) + ", " + getFirstLessThanEqual(xs, 2) + " was not greater than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThanEqual(xs, 2) + " was not greater than 2")
  }
  def `Seq(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not be greater than comparison' failed` {
    val xs = Seq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be > (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThan(xs, 2)) + ", " + getFirstMoreThan(xs, 2) + " was greater than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThan(xs, 2) + " was greater than 2")
  }
  def `Seq(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should be greater than or equal comparison' failed` {
    val xs = Seq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be >= 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThan(xs, 2)) + ", " + getFirstLessThan(xs, 2) + " was not greater than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThan(xs, 2) + " was not greater than or equal to 2")
  }
  def `Seq(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not be greater than or equal comparison' failed` {
    val xs = Seq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be >= (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThanEqual(xs, 2)) + ", " + getFirstMoreThanEqual(xs, 2) + " was greater than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThanEqual(xs, 2) + " was greater than or equal to 2")
  }
  def `Seq(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should be ===' failed` {
    val xs = Seq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be === 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[Int](xs, 2)) + ", " + getFirstNotEqual[Int](xs, 2) + " was not equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstNotEqual[Int](xs, 2) + " was not equal to 2")
  }
  def `Seq(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not be ===' failed` {
    val xs = Seq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be === (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " was equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " was equal to 2")
  }
  def `Array(1, 2, 3) should throw TestFailedException with correct stack depth and message when at least one element failed` {
    val xs = Array(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not equal 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " equaled 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + "WrappedArray(1, 2, 3)", "" + getFirstEqual[Int](xs, 2) + " equaled 2")
  }
  def `Array(1, 2, 3) should throw TestFailedException with correct stack depth and message when more than one element failed` {
    val xs = Array(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be < 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThanEqual(xs, 2)) + ", " + getFirstMoreThanEqual(xs, 2) + " was not less than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + "WrappedArray(1, 2, 3)", "" + getFirstMoreThanEqual(xs, 2) + " was not less than 2")
  }
  def `Array(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should equal' failed` {
    val xs = Array(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should equal (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[Int](xs, 2)) + ", " + getFirstNotEqual[Int](xs, 2) + " did not equal 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + "WrappedArray(1, 2, 3)", "" + getFirstNotEqual[Int](xs, 2) + " did not equal 2")
  }
  def `Array(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not equal' failed` {
    val xs = Array(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not equal 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " equaled 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + "WrappedArray(1, 2, 3)", "" + getFirstEqual[Int](xs, 2) + " equaled 2")
  }
  def `Array(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should be' failed` {
    val xs = Array(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[Int](xs, 2)) + ", " + getFirstNotEqual[Int](xs, 2) + " was not equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + "WrappedArray(1, 2, 3)", "" + getFirstNotEqual[Int](xs, 2) + " was not equal to 2")
  }
  def `Array(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not be' failed` {
    val xs = Array(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " was equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + "WrappedArray(1, 2, 3)", "" + getFirstEqual[Int](xs, 2) + " was equal to 2")
  }
  def `Array(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should be less than comparison' failed` {
    val xs = Array(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be < 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThanEqual(xs, 2)) + ", " + getFirstMoreThanEqual(xs, 2) + " was not less than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + "WrappedArray(1, 2, 3)", "" + getFirstMoreThanEqual(xs, 2) + " was not less than 2")
  }
  def `Array(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not be less than comparison' failed` {
    val xs = Array(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be < (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThan(xs, 2)) + ", " + getFirstLessThan(xs, 2) + " was less than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + "WrappedArray(1, 2, 3)", "" + getFirstLessThan(xs, 2) + " was less than 2")
  }
  def `Array(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should be less than or equal comparison' failed` {
    val xs = Array(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be <= 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThan(xs, 2)) + ", " + getFirstMoreThan(xs, 2) + " was not less than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + "WrappedArray(1, 2, 3)", "" + getFirstMoreThan(xs, 2) + " was not less than or equal to 2")
  }
  def `Array(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not be less than or equal comparison' failed` {
    val xs = Array(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be <= (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThanEqual(xs, 2)) + ", " + getFirstLessThanEqual(xs, 2) + " was less than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + "WrappedArray(1, 2, 3)", "" + getFirstLessThanEqual(xs, 2) + " was less than or equal to 2")
  }
  def `Array(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should be greater than comparison' failed` {
    val xs = Array(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be > 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThanEqual(xs, 2)) + ", " + getFirstLessThanEqual(xs, 2) + " was not greater than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + "WrappedArray(1, 2, 3)", "" + getFirstLessThanEqual(xs, 2) + " was not greater than 2")
  }
  def `Array(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not be greater than comparison' failed` {
    val xs = Array(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be > (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThan(xs, 2)) + ", " + getFirstMoreThan(xs, 2) + " was greater than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + "WrappedArray(1, 2, 3)", "" + getFirstMoreThan(xs, 2) + " was greater than 2")
  }
  def `Array(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should be greater than or equal comparison' failed` {
    val xs = Array(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be >= 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThan(xs, 2)) + ", " + getFirstLessThan(xs, 2) + " was not greater than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + "WrappedArray(1, 2, 3)", "" + getFirstLessThan(xs, 2) + " was not greater than or equal to 2")
  }
  def `Array(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not be greater than or equal comparison' failed` {
    val xs = Array(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be >= (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThanEqual(xs, 2)) + ", " + getFirstMoreThanEqual(xs, 2) + " was greater than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + "WrappedArray(1, 2, 3)", "" + getFirstMoreThanEqual(xs, 2) + " was greater than or equal to 2")
  }
  def `Array(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should be ===' failed` {
    val xs = Array(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be === 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[Int](xs, 2)) + ", " + getFirstNotEqual[Int](xs, 2) + " was not equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + "WrappedArray(1, 2, 3)", "" + getFirstNotEqual[Int](xs, 2) + " was not equal to 2")
  }
  def `Array(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not be ===' failed` {
    val xs = Array(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be === (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " was equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + "WrappedArray(1, 2, 3)", "" + getFirstEqual[Int](xs, 2) + " was equal to 2")
  }
  def `IndexedSeq(1, 2, 3) should throw TestFailedException with correct stack depth and message when at least one element failed` {
    val xs = IndexedSeq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not equal 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " equaled 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " equaled 2")
  }
  def `IndexedSeq(1, 2, 3) should throw TestFailedException with correct stack depth and message when more than one element failed` {
    val xs = IndexedSeq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be < 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThanEqual(xs, 2)) + ", " + getFirstMoreThanEqual(xs, 2) + " was not less than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThanEqual(xs, 2) + " was not less than 2")
  }
  def `IndexedSeq(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should equal' failed` {
    val xs = IndexedSeq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should equal (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[Int](xs, 2)) + ", " + getFirstNotEqual[Int](xs, 2) + " did not equal 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstNotEqual[Int](xs, 2) + " did not equal 2")
  }
  def `IndexedSeq(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not equal' failed` {
    val xs = IndexedSeq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not equal 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " equaled 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " equaled 2")
  }
  def `IndexedSeq(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should be' failed` {
    val xs = IndexedSeq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[Int](xs, 2)) + ", " + getFirstNotEqual[Int](xs, 2) + " was not equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstNotEqual[Int](xs, 2) + " was not equal to 2")
  }
  def `IndexedSeq(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not be' failed` {
    val xs = IndexedSeq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " was equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " was equal to 2")
  }
  def `IndexedSeq(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should be less than comparison' failed` {
    val xs = IndexedSeq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be < 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThanEqual(xs, 2)) + ", " + getFirstMoreThanEqual(xs, 2) + " was not less than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThanEqual(xs, 2) + " was not less than 2")
  }
  def `IndexedSeq(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not be less than comparison' failed` {
    val xs = IndexedSeq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be < (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThan(xs, 2)) + ", " + getFirstLessThan(xs, 2) + " was less than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThan(xs, 2) + " was less than 2")
  }
  def `IndexedSeq(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should be less than or equal comparison' failed` {
    val xs = IndexedSeq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be <= 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThan(xs, 2)) + ", " + getFirstMoreThan(xs, 2) + " was not less than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThan(xs, 2) + " was not less than or equal to 2")
  }
  def `IndexedSeq(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not be less than or equal comparison' failed` {
    val xs = IndexedSeq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be <= (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThanEqual(xs, 2)) + ", " + getFirstLessThanEqual(xs, 2) + " was less than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThanEqual(xs, 2) + " was less than or equal to 2")
  }
  def `IndexedSeq(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should be greater than comparison' failed` {
    val xs = IndexedSeq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be > 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThanEqual(xs, 2)) + ", " + getFirstLessThanEqual(xs, 2) + " was not greater than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThanEqual(xs, 2) + " was not greater than 2")
  }
  def `IndexedSeq(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not be greater than comparison' failed` {
    val xs = IndexedSeq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be > (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThan(xs, 2)) + ", " + getFirstMoreThan(xs, 2) + " was greater than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThan(xs, 2) + " was greater than 2")
  }
  def `IndexedSeq(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should be greater than or equal comparison' failed` {
    val xs = IndexedSeq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be >= 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThan(xs, 2)) + ", " + getFirstLessThan(xs, 2) + " was not greater than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThan(xs, 2) + " was not greater than or equal to 2")
  }
  def `IndexedSeq(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not be greater than or equal comparison' failed` {
    val xs = IndexedSeq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be >= (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThanEqual(xs, 2)) + ", " + getFirstMoreThanEqual(xs, 2) + " was greater than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThanEqual(xs, 2) + " was greater than or equal to 2")
  }
  def `IndexedSeq(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should be ===' failed` {
    val xs = IndexedSeq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be === 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[Int](xs, 2)) + ", " + getFirstNotEqual[Int](xs, 2) + " was not equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstNotEqual[Int](xs, 2) + " was not equal to 2")
  }
  def `IndexedSeq(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not be ===' failed` {
    val xs = IndexedSeq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be === (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " was equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " was equal to 2")
  }
  def `Vector(1, 2, 3) should throw TestFailedException with correct stack depth and message when at least one element failed` {
    val xs = Vector(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not equal 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " equaled 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " equaled 2")
  }
  def `Vector(1, 2, 3) should throw TestFailedException with correct stack depth and message when more than one element failed` {
    val xs = Vector(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be < 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThanEqual(xs, 2)) + ", " + getFirstMoreThanEqual(xs, 2) + " was not less than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThanEqual(xs, 2) + " was not less than 2")
  }
  def `Vector(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should equal' failed` {
    val xs = Vector(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should equal (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[Int](xs, 2)) + ", " + getFirstNotEqual[Int](xs, 2) + " did not equal 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstNotEqual[Int](xs, 2) + " did not equal 2")
  }
  def `Vector(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not equal' failed` {
    val xs = Vector(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not equal 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " equaled 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " equaled 2")
  }
  def `Vector(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should be' failed` {
    val xs = Vector(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[Int](xs, 2)) + ", " + getFirstNotEqual[Int](xs, 2) + " was not equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstNotEqual[Int](xs, 2) + " was not equal to 2")
  }
  def `Vector(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not be' failed` {
    val xs = Vector(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " was equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " was equal to 2")
  }
  def `Vector(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should be less than comparison' failed` {
    val xs = Vector(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be < 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThanEqual(xs, 2)) + ", " + getFirstMoreThanEqual(xs, 2) + " was not less than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThanEqual(xs, 2) + " was not less than 2")
  }
  def `Vector(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not be less than comparison' failed` {
    val xs = Vector(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be < (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThan(xs, 2)) + ", " + getFirstLessThan(xs, 2) + " was less than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThan(xs, 2) + " was less than 2")
  }
  def `Vector(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should be less than or equal comparison' failed` {
    val xs = Vector(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be <= 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThan(xs, 2)) + ", " + getFirstMoreThan(xs, 2) + " was not less than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThan(xs, 2) + " was not less than or equal to 2")
  }
  def `Vector(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not be less than or equal comparison' failed` {
    val xs = Vector(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be <= (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThanEqual(xs, 2)) + ", " + getFirstLessThanEqual(xs, 2) + " was less than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThanEqual(xs, 2) + " was less than or equal to 2")
  }
  def `Vector(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should be greater than comparison' failed` {
    val xs = Vector(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be > 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThanEqual(xs, 2)) + ", " + getFirstLessThanEqual(xs, 2) + " was not greater than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThanEqual(xs, 2) + " was not greater than 2")
  }
  def `Vector(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not be greater than comparison' failed` {
    val xs = Vector(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be > (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThan(xs, 2)) + ", " + getFirstMoreThan(xs, 2) + " was greater than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThan(xs, 2) + " was greater than 2")
  }
  def `Vector(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should be greater than or equal comparison' failed` {
    val xs = Vector(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be >= 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThan(xs, 2)) + ", " + getFirstLessThan(xs, 2) + " was not greater than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThan(xs, 2) + " was not greater than or equal to 2")
  }
  def `Vector(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not be greater than or equal comparison' failed` {
    val xs = Vector(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be >= (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThanEqual(xs, 2)) + ", " + getFirstMoreThanEqual(xs, 2) + " was greater than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThanEqual(xs, 2) + " was greater than or equal to 2")
  }
  def `Vector(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should be ===' failed` {
    val xs = Vector(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be === 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[Int](xs, 2)) + ", " + getFirstNotEqual[Int](xs, 2) + " was not equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstNotEqual[Int](xs, 2) + " was not equal to 2")
  }
  def `Vector(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not be ===' failed` {
    val xs = Vector(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be === (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " was equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " was equal to 2")
  }
  def `Set(1, 2, 3).par should throw TestFailedException with correct stack depth and message when at least one element failed` {
    val xs = Set(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not equal 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " equaled 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " equaled 2")
  }
  def `Set(1, 2, 3).par should throw TestFailedException with correct stack depth and message when more than one element failed` {
    val xs = Set(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be < 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThanEqual(xs, 2)) + ", " + getFirstMoreThanEqual(xs, 2) + " was not less than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThanEqual(xs, 2) + " was not less than 2")
  }
  def `Set(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should equal' failed` {
    val xs = Set(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should equal (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[Int](xs, 2)) + ", " + getFirstNotEqual[Int](xs, 2) + " did not equal 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstNotEqual[Int](xs, 2) + " did not equal 2")
  }
  def `Set(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should not equal' failed` {
    val xs = Set(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not equal 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " equaled 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " equaled 2")
  }
  def `Set(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should be' failed` {
    val xs = Set(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[Int](xs, 2)) + ", " + getFirstNotEqual[Int](xs, 2) + " was not equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstNotEqual[Int](xs, 2) + " was not equal to 2")
  }
  def `Set(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should not be' failed` {
    val xs = Set(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " was equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " was equal to 2")
  }
  def `Set(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should be less than comparison' failed` {
    val xs = Set(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be < 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThanEqual(xs, 2)) + ", " + getFirstMoreThanEqual(xs, 2) + " was not less than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThanEqual(xs, 2) + " was not less than 2")
  }
  def `Set(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should not be less than comparison' failed` {
    val xs = Set(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be < (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThan(xs, 2)) + ", " + getFirstLessThan(xs, 2) + " was less than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThan(xs, 2) + " was less than 2")
  }
  def `Set(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should be less than or equal comparison' failed` {
    val xs = Set(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be <= 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThan(xs, 2)) + ", " + getFirstMoreThan(xs, 2) + " was not less than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThan(xs, 2) + " was not less than or equal to 2")
  }
  def `Set(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should not be less than or equal comparison' failed` {
    val xs = Set(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be <= (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThanEqual(xs, 2)) + ", " + getFirstLessThanEqual(xs, 2) + " was less than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThanEqual(xs, 2) + " was less than or equal to 2")
  }
  def `Set(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should be greater than comparison' failed` {
    val xs = Set(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be > 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThanEqual(xs, 2)) + ", " + getFirstLessThanEqual(xs, 2) + " was not greater than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThanEqual(xs, 2) + " was not greater than 2")
  }
  def `Set(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should not be greater than comparison' failed` {
    val xs = Set(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be > (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThan(xs, 2)) + ", " + getFirstMoreThan(xs, 2) + " was greater than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThan(xs, 2) + " was greater than 2")
  }
  def `Set(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should be greater than or equal comparison' failed` {
    val xs = Set(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be >= 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThan(xs, 2)) + ", " + getFirstLessThan(xs, 2) + " was not greater than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThan(xs, 2) + " was not greater than or equal to 2")
  }
  def `Set(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should not be greater than or equal comparison' failed` {
    val xs = Set(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be >= (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThanEqual(xs, 2)) + ", " + getFirstMoreThanEqual(xs, 2) + " was greater than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThanEqual(xs, 2) + " was greater than or equal to 2")
  }
  def `Set(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should be ===' failed` {
    val xs = Set(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be === 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[Int](xs, 2)) + ", " + getFirstNotEqual[Int](xs, 2) + " was not equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstNotEqual[Int](xs, 2) + " was not equal to 2")
  }
  def `Set(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should not be ===' failed` {
    val xs = Set(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be === (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " was equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " was equal to 2")
  }
  def `List(1, 2, 3).par should throw TestFailedException with correct stack depth and message when at least one element failed` {
    val xs = List(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not equal 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " equaled 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " equaled 2")
  }
  def `List(1, 2, 3).par should throw TestFailedException with correct stack depth and message when more than one element failed` {
    val xs = List(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be < 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThanEqual(xs, 2)) + ", " + getFirstMoreThanEqual(xs, 2) + " was not less than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThanEqual(xs, 2) + " was not less than 2")
  }
  def `List(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should equal' failed` {
    val xs = List(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should equal (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[Int](xs, 2)) + ", " + getFirstNotEqual[Int](xs, 2) + " did not equal 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstNotEqual[Int](xs, 2) + " did not equal 2")
  }
  def `List(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should not equal' failed` {
    val xs = List(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not equal 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " equaled 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " equaled 2")
  }
  def `List(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should be' failed` {
    val xs = List(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[Int](xs, 2)) + ", " + getFirstNotEqual[Int](xs, 2) + " was not equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstNotEqual[Int](xs, 2) + " was not equal to 2")
  }
  def `List(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should not be' failed` {
    val xs = List(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " was equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " was equal to 2")
  }
  def `List(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should be less than comparison' failed` {
    val xs = List(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be < 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThanEqual(xs, 2)) + ", " + getFirstMoreThanEqual(xs, 2) + " was not less than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThanEqual(xs, 2) + " was not less than 2")
  }
  def `List(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should not be less than comparison' failed` {
    val xs = List(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be < (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThan(xs, 2)) + ", " + getFirstLessThan(xs, 2) + " was less than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThan(xs, 2) + " was less than 2")
  }
  def `List(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should be less than or equal comparison' failed` {
    val xs = List(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be <= 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThan(xs, 2)) + ", " + getFirstMoreThan(xs, 2) + " was not less than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThan(xs, 2) + " was not less than or equal to 2")
  }
  def `List(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should not be less than or equal comparison' failed` {
    val xs = List(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be <= (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThanEqual(xs, 2)) + ", " + getFirstLessThanEqual(xs, 2) + " was less than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThanEqual(xs, 2) + " was less than or equal to 2")
  }
  def `List(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should be greater than comparison' failed` {
    val xs = List(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be > 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThanEqual(xs, 2)) + ", " + getFirstLessThanEqual(xs, 2) + " was not greater than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThanEqual(xs, 2) + " was not greater than 2")
  }
  def `List(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should not be greater than comparison' failed` {
    val xs = List(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be > (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThan(xs, 2)) + ", " + getFirstMoreThan(xs, 2) + " was greater than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThan(xs, 2) + " was greater than 2")
  }
  def `List(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should be greater than or equal comparison' failed` {
    val xs = List(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be >= 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThan(xs, 2)) + ", " + getFirstLessThan(xs, 2) + " was not greater than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThan(xs, 2) + " was not greater than or equal to 2")
  }
  def `List(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should not be greater than or equal comparison' failed` {
    val xs = List(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be >= (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThanEqual(xs, 2)) + ", " + getFirstMoreThanEqual(xs, 2) + " was greater than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThanEqual(xs, 2) + " was greater than or equal to 2")
  }
  def `List(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should be ===' failed` {
    val xs = List(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be === 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[Int](xs, 2)) + ", " + getFirstNotEqual[Int](xs, 2) + " was not equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstNotEqual[Int](xs, 2) + " was not equal to 2")
  }
  def `List(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should not be ===' failed` {
    val xs = List(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be === (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " was equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " was equal to 2")
  }
  def `Seq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when at least one element failed` {
    val xs = Seq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not equal 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " equaled 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " equaled 2")
  }
  def `Seq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when more than one element failed` {
    val xs = Seq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be < 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThanEqual(xs, 2)) + ", " + getFirstMoreThanEqual(xs, 2) + " was not less than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThanEqual(xs, 2) + " was not less than 2")
  }
  def `Seq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should equal' failed` {
    val xs = Seq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should equal (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[Int](xs, 2)) + ", " + getFirstNotEqual[Int](xs, 2) + " did not equal 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstNotEqual[Int](xs, 2) + " did not equal 2")
  }
  def `Seq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should not equal' failed` {
    val xs = Seq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not equal 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " equaled 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " equaled 2")
  }
  def `Seq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should be' failed` {
    val xs = Seq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[Int](xs, 2)) + ", " + getFirstNotEqual[Int](xs, 2) + " was not equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstNotEqual[Int](xs, 2) + " was not equal to 2")
  }
  def `Seq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should not be' failed` {
    val xs = Seq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " was equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " was equal to 2")
  }
  def `Seq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should be less than comparison' failed` {
    val xs = Seq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be < 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThanEqual(xs, 2)) + ", " + getFirstMoreThanEqual(xs, 2) + " was not less than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThanEqual(xs, 2) + " was not less than 2")
  }
  def `Seq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should not be less than comparison' failed` {
    val xs = Seq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be < (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThan(xs, 2)) + ", " + getFirstLessThan(xs, 2) + " was less than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThan(xs, 2) + " was less than 2")
  }
  def `Seq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should be less than or equal comparison' failed` {
    val xs = Seq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be <= 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThan(xs, 2)) + ", " + getFirstMoreThan(xs, 2) + " was not less than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThan(xs, 2) + " was not less than or equal to 2")
  }
  def `Seq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should not be less than or equal comparison' failed` {
    val xs = Seq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be <= (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThanEqual(xs, 2)) + ", " + getFirstLessThanEqual(xs, 2) + " was less than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThanEqual(xs, 2) + " was less than or equal to 2")
  }
  def `Seq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should be greater than comparison' failed` {
    val xs = Seq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be > 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThanEqual(xs, 2)) + ", " + getFirstLessThanEqual(xs, 2) + " was not greater than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThanEqual(xs, 2) + " was not greater than 2")
  }
  def `Seq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should not be greater than comparison' failed` {
    val xs = Seq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be > (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThan(xs, 2)) + ", " + getFirstMoreThan(xs, 2) + " was greater than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThan(xs, 2) + " was greater than 2")
  }
  def `Seq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should be greater than or equal comparison' failed` {
    val xs = Seq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be >= 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThan(xs, 2)) + ", " + getFirstLessThan(xs, 2) + " was not greater than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThan(xs, 2) + " was not greater than or equal to 2")
  }
  def `Seq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should not be greater than or equal comparison' failed` {
    val xs = Seq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be >= (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThanEqual(xs, 2)) + ", " + getFirstMoreThanEqual(xs, 2) + " was greater than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThanEqual(xs, 2) + " was greater than or equal to 2")
  }
  def `Seq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should be ===' failed` {
    val xs = Seq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be === 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[Int](xs, 2)) + ", " + getFirstNotEqual[Int](xs, 2) + " was not equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstNotEqual[Int](xs, 2) + " was not equal to 2")
  }
  def `Seq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should not be ===' failed` {
    val xs = Seq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be === (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " was equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " was equal to 2")
  }
  def `IndexedSeq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when at least one element failed` {
    val xs = IndexedSeq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not equal 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " equaled 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " equaled 2")
  }
  def `IndexedSeq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when more than one element failed` {
    val xs = IndexedSeq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be < 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThanEqual(xs, 2)) + ", " + getFirstMoreThanEqual(xs, 2) + " was not less than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThanEqual(xs, 2) + " was not less than 2")
  }
  def `IndexedSeq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should equal' failed` {
    val xs = IndexedSeq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should equal (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[Int](xs, 2)) + ", " + getFirstNotEqual[Int](xs, 2) + " did not equal 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstNotEqual[Int](xs, 2) + " did not equal 2")
  }
  def `IndexedSeq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should not equal' failed` {
    val xs = IndexedSeq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not equal 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " equaled 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " equaled 2")
  }
  def `IndexedSeq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should be' failed` {
    val xs = IndexedSeq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[Int](xs, 2)) + ", " + getFirstNotEqual[Int](xs, 2) + " was not equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstNotEqual[Int](xs, 2) + " was not equal to 2")
  }
  def `IndexedSeq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should not be' failed` {
    val xs = IndexedSeq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " was equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " was equal to 2")
  }
  def `IndexedSeq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should be less than comparison' failed` {
    val xs = IndexedSeq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be < 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThanEqual(xs, 2)) + ", " + getFirstMoreThanEqual(xs, 2) + " was not less than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThanEqual(xs, 2) + " was not less than 2")
  }
  def `IndexedSeq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should not be less than comparison' failed` {
    val xs = IndexedSeq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be < (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThan(xs, 2)) + ", " + getFirstLessThan(xs, 2) + " was less than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThan(xs, 2) + " was less than 2")
  }
  def `IndexedSeq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should be less than or equal comparison' failed` {
    val xs = IndexedSeq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be <= 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThan(xs, 2)) + ", " + getFirstMoreThan(xs, 2) + " was not less than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThan(xs, 2) + " was not less than or equal to 2")
  }
  def `IndexedSeq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should not be less than or equal comparison' failed` {
    val xs = IndexedSeq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be <= (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThanEqual(xs, 2)) + ", " + getFirstLessThanEqual(xs, 2) + " was less than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThanEqual(xs, 2) + " was less than or equal to 2")
  }
  def `IndexedSeq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should be greater than comparison' failed` {
    val xs = IndexedSeq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be > 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThanEqual(xs, 2)) + ", " + getFirstLessThanEqual(xs, 2) + " was not greater than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThanEqual(xs, 2) + " was not greater than 2")
  }
  def `IndexedSeq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should not be greater than comparison' failed` {
    val xs = IndexedSeq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be > (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThan(xs, 2)) + ", " + getFirstMoreThan(xs, 2) + " was greater than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThan(xs, 2) + " was greater than 2")
  }
  def `IndexedSeq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should be greater than or equal comparison' failed` {
    val xs = IndexedSeq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be >= 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThan(xs, 2)) + ", " + getFirstLessThan(xs, 2) + " was not greater than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThan(xs, 2) + " was not greater than or equal to 2")
  }
  def `IndexedSeq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should not be greater than or equal comparison' failed` {
    val xs = IndexedSeq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be >= (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThanEqual(xs, 2)) + ", " + getFirstMoreThanEqual(xs, 2) + " was greater than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThanEqual(xs, 2) + " was greater than or equal to 2")
  }
  def `IndexedSeq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should be ===' failed` {
    val xs = IndexedSeq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be === 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[Int](xs, 2)) + ", " + getFirstNotEqual[Int](xs, 2) + " was not equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstNotEqual[Int](xs, 2) + " was not equal to 2")
  }
  def `IndexedSeq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should not be ===' failed` {
    val xs = IndexedSeq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be === (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " was equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " was equal to 2")
  }
  def `collection.mutable.Set(1, 2, 3) should throw TestFailedException with correct stack depth and message when at least one element failed` {
    val xs = collection.mutable.Set(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not equal 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " equaled 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " equaled 2")
  }
  def `collection.mutable.Set(1, 2, 3) should throw TestFailedException with correct stack depth and message when more than one element failed` {
    val xs = collection.mutable.Set(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be < 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThanEqual(xs, 2)) + ", " + getFirstMoreThanEqual(xs, 2) + " was not less than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThanEqual(xs, 2) + " was not less than 2")
  }
  def `collection.mutable.Set(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should equal' failed` {
    val xs = collection.mutable.Set(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should equal (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[Int](xs, 2)) + ", " + getFirstNotEqual[Int](xs, 2) + " did not equal 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstNotEqual[Int](xs, 2) + " did not equal 2")
  }
  def `collection.mutable.Set(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not equal' failed` {
    val xs = collection.mutable.Set(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not equal 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " equaled 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " equaled 2")
  }
  def `collection.mutable.Set(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should be' failed` {
    val xs = collection.mutable.Set(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[Int](xs, 2)) + ", " + getFirstNotEqual[Int](xs, 2) + " was not equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstNotEqual[Int](xs, 2) + " was not equal to 2")
  }
  def `collection.mutable.Set(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not be' failed` {
    val xs = collection.mutable.Set(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " was equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " was equal to 2")
  }
  def `collection.mutable.Set(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should be less than comparison' failed` {
    val xs = collection.mutable.Set(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be < 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThanEqual(xs, 2)) + ", " + getFirstMoreThanEqual(xs, 2) + " was not less than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThanEqual(xs, 2) + " was not less than 2")
  }
  def `collection.mutable.Set(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not be less than comparison' failed` {
    val xs = collection.mutable.Set(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be < (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThan(xs, 2)) + ", " + getFirstLessThan(xs, 2) + " was less than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThan(xs, 2) + " was less than 2")
  }
  def `collection.mutable.Set(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should be less than or equal comparison' failed` {
    val xs = collection.mutable.Set(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be <= 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThan(xs, 2)) + ", " + getFirstMoreThan(xs, 2) + " was not less than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThan(xs, 2) + " was not less than or equal to 2")
  }
  def `collection.mutable.Set(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not be less than or equal comparison' failed` {
    val xs = collection.mutable.Set(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be <= (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThanEqual(xs, 2)) + ", " + getFirstLessThanEqual(xs, 2) + " was less than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThanEqual(xs, 2) + " was less than or equal to 2")
  }
  def `collection.mutable.Set(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should be greater than comparison' failed` {
    val xs = collection.mutable.Set(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be > 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThanEqual(xs, 2)) + ", " + getFirstLessThanEqual(xs, 2) + " was not greater than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThanEqual(xs, 2) + " was not greater than 2")
  }
  def `collection.mutable.Set(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not be greater than comparison' failed` {
    val xs = collection.mutable.Set(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be > (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThan(xs, 2)) + ", " + getFirstMoreThan(xs, 2) + " was greater than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThan(xs, 2) + " was greater than 2")
  }
  def `collection.mutable.Set(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should be greater than or equal comparison' failed` {
    val xs = collection.mutable.Set(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be >= 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThan(xs, 2)) + ", " + getFirstLessThan(xs, 2) + " was not greater than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThan(xs, 2) + " was not greater than or equal to 2")
  }
  def `collection.mutable.Set(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not be greater than or equal comparison' failed` {
    val xs = collection.mutable.Set(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be >= (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThanEqual(xs, 2)) + ", " + getFirstMoreThanEqual(xs, 2) + " was greater than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThanEqual(xs, 2) + " was greater than or equal to 2")
  }
  def `collection.mutable.Set(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should be ===' failed` {
    val xs = collection.mutable.Set(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be === 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[Int](xs, 2)) + ", " + getFirstNotEqual[Int](xs, 2) + " was not equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstNotEqual[Int](xs, 2) + " was not equal to 2")
  }
  def `collection.mutable.Set(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not be ===' failed` {
    val xs = collection.mutable.Set(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be === (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " was equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " was equal to 2")
  }
  def `new collection.mutable.ListBuffer() ++ List(1, 2, 3) should throw TestFailedException with correct stack depth and message when at least one element failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not equal 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " equaled 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " equaled 2")
  }
  def `new collection.mutable.ListBuffer() ++ List(1, 2, 3) should throw TestFailedException with correct stack depth and message when more than one element failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be < 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThanEqual(xs, 2)) + ", " + getFirstMoreThanEqual(xs, 2) + " was not less than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThanEqual(xs, 2) + " was not less than 2")
  }
  def `new collection.mutable.ListBuffer() ++ List(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should equal' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should equal (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[Int](xs, 2)) + ", " + getFirstNotEqual[Int](xs, 2) + " did not equal 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstNotEqual[Int](xs, 2) + " did not equal 2")
  }
  def `new collection.mutable.ListBuffer() ++ List(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not equal' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not equal 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " equaled 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " equaled 2")
  }
  def `new collection.mutable.ListBuffer() ++ List(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should be' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[Int](xs, 2)) + ", " + getFirstNotEqual[Int](xs, 2) + " was not equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstNotEqual[Int](xs, 2) + " was not equal to 2")
  }
  def `new collection.mutable.ListBuffer() ++ List(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not be' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " was equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " was equal to 2")
  }
  def `new collection.mutable.ListBuffer() ++ List(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should be less than comparison' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be < 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThanEqual(xs, 2)) + ", " + getFirstMoreThanEqual(xs, 2) + " was not less than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThanEqual(xs, 2) + " was not less than 2")
  }
  def `new collection.mutable.ListBuffer() ++ List(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not be less than comparison' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be < (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThan(xs, 2)) + ", " + getFirstLessThan(xs, 2) + " was less than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThan(xs, 2) + " was less than 2")
  }
  def `new collection.mutable.ListBuffer() ++ List(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should be less than or equal comparison' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be <= 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThan(xs, 2)) + ", " + getFirstMoreThan(xs, 2) + " was not less than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThan(xs, 2) + " was not less than or equal to 2")
  }
  def `new collection.mutable.ListBuffer() ++ List(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not be less than or equal comparison' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be <= (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThanEqual(xs, 2)) + ", " + getFirstLessThanEqual(xs, 2) + " was less than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThanEqual(xs, 2) + " was less than or equal to 2")
  }
  def `new collection.mutable.ListBuffer() ++ List(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should be greater than comparison' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be > 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThanEqual(xs, 2)) + ", " + getFirstLessThanEqual(xs, 2) + " was not greater than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThanEqual(xs, 2) + " was not greater than 2")
  }
  def `new collection.mutable.ListBuffer() ++ List(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not be greater than comparison' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be > (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThan(xs, 2)) + ", " + getFirstMoreThan(xs, 2) + " was greater than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThan(xs, 2) + " was greater than 2")
  }
  def `new collection.mutable.ListBuffer() ++ List(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should be greater than or equal comparison' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be >= 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThan(xs, 2)) + ", " + getFirstLessThan(xs, 2) + " was not greater than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThan(xs, 2) + " was not greater than or equal to 2")
  }
  def `new collection.mutable.ListBuffer() ++ List(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not be greater than or equal comparison' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be >= (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThanEqual(xs, 2)) + ", " + getFirstMoreThanEqual(xs, 2) + " was greater than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThanEqual(xs, 2) + " was greater than or equal to 2")
  }
  def `new collection.mutable.ListBuffer() ++ List(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should be ===' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be === 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[Int](xs, 2)) + ", " + getFirstNotEqual[Int](xs, 2) + " was not equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstNotEqual[Int](xs, 2) + " was not equal to 2")
  }
  def `new collection.mutable.ListBuffer() ++ List(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not be ===' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be === (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " was equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " was equal to 2")
  }
  def `collection.mutable.Seq(1, 2, 3) should throw TestFailedException with correct stack depth and message when at least one element failed` {
    val xs = collection.mutable.Seq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not equal 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " equaled 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " equaled 2")
  }
  def `collection.mutable.Seq(1, 2, 3) should throw TestFailedException with correct stack depth and message when more than one element failed` {
    val xs = collection.mutable.Seq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be < 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThanEqual(xs, 2)) + ", " + getFirstMoreThanEqual(xs, 2) + " was not less than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThanEqual(xs, 2) + " was not less than 2")
  }
  def `collection.mutable.Seq(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should equal' failed` {
    val xs = collection.mutable.Seq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should equal (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[Int](xs, 2)) + ", " + getFirstNotEqual[Int](xs, 2) + " did not equal 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstNotEqual[Int](xs, 2) + " did not equal 2")
  }
  def `collection.mutable.Seq(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not equal' failed` {
    val xs = collection.mutable.Seq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not equal 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " equaled 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " equaled 2")
  }
  def `collection.mutable.Seq(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should be' failed` {
    val xs = collection.mutable.Seq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[Int](xs, 2)) + ", " + getFirstNotEqual[Int](xs, 2) + " was not equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstNotEqual[Int](xs, 2) + " was not equal to 2")
  }
  def `collection.mutable.Seq(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not be' failed` {
    val xs = collection.mutable.Seq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " was equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " was equal to 2")
  }
  def `collection.mutable.Seq(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should be less than comparison' failed` {
    val xs = collection.mutable.Seq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be < 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThanEqual(xs, 2)) + ", " + getFirstMoreThanEqual(xs, 2) + " was not less than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThanEqual(xs, 2) + " was not less than 2")
  }
  def `collection.mutable.Seq(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not be less than comparison' failed` {
    val xs = collection.mutable.Seq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be < (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThan(xs, 2)) + ", " + getFirstLessThan(xs, 2) + " was less than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThan(xs, 2) + " was less than 2")
  }
  def `collection.mutable.Seq(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should be less than or equal comparison' failed` {
    val xs = collection.mutable.Seq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be <= 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThan(xs, 2)) + ", " + getFirstMoreThan(xs, 2) + " was not less than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThan(xs, 2) + " was not less than or equal to 2")
  }
  def `collection.mutable.Seq(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not be less than or equal comparison' failed` {
    val xs = collection.mutable.Seq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be <= (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThanEqual(xs, 2)) + ", " + getFirstLessThanEqual(xs, 2) + " was less than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThanEqual(xs, 2) + " was less than or equal to 2")
  }
  def `collection.mutable.Seq(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should be greater than comparison' failed` {
    val xs = collection.mutable.Seq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be > 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThanEqual(xs, 2)) + ", " + getFirstLessThanEqual(xs, 2) + " was not greater than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThanEqual(xs, 2) + " was not greater than 2")
  }
  def `collection.mutable.Seq(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not be greater than comparison' failed` {
    val xs = collection.mutable.Seq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be > (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThan(xs, 2)) + ", " + getFirstMoreThan(xs, 2) + " was greater than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThan(xs, 2) + " was greater than 2")
  }
  def `collection.mutable.Seq(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should be greater than or equal comparison' failed` {
    val xs = collection.mutable.Seq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be >= 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThan(xs, 2)) + ", " + getFirstLessThan(xs, 2) + " was not greater than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThan(xs, 2) + " was not greater than or equal to 2")
  }
  def `collection.mutable.Seq(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not be greater than or equal comparison' failed` {
    val xs = collection.mutable.Seq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be >= (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThanEqual(xs, 2)) + ", " + getFirstMoreThanEqual(xs, 2) + " was greater than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThanEqual(xs, 2) + " was greater than or equal to 2")
  }
  def `collection.mutable.Seq(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should be ===' failed` {
    val xs = collection.mutable.Seq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be === 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[Int](xs, 2)) + ", " + getFirstNotEqual[Int](xs, 2) + " was not equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstNotEqual[Int](xs, 2) + " was not equal to 2")
  }
  def `collection.mutable.Seq(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not be ===' failed` {
    val xs = collection.mutable.Seq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be === (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " was equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " was equal to 2")
  }
  def `collection.mutable.IndexedSeq(1, 2, 3) should throw TestFailedException with correct stack depth and message when at least one element failed` {
    val xs = collection.mutable.IndexedSeq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not equal 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " equaled 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " equaled 2")
  }
  def `collection.mutable.IndexedSeq(1, 2, 3) should throw TestFailedException with correct stack depth and message when more than one element failed` {
    val xs = collection.mutable.IndexedSeq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be < 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThanEqual(xs, 2)) + ", " + getFirstMoreThanEqual(xs, 2) + " was not less than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThanEqual(xs, 2) + " was not less than 2")
  }
  def `collection.mutable.IndexedSeq(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should equal' failed` {
    val xs = collection.mutable.IndexedSeq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should equal (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[Int](xs, 2)) + ", " + getFirstNotEqual[Int](xs, 2) + " did not equal 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstNotEqual[Int](xs, 2) + " did not equal 2")
  }
  def `collection.mutable.IndexedSeq(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not equal' failed` {
    val xs = collection.mutable.IndexedSeq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not equal 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " equaled 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " equaled 2")
  }
  def `collection.mutable.IndexedSeq(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should be' failed` {
    val xs = collection.mutable.IndexedSeq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[Int](xs, 2)) + ", " + getFirstNotEqual[Int](xs, 2) + " was not equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstNotEqual[Int](xs, 2) + " was not equal to 2")
  }
  def `collection.mutable.IndexedSeq(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not be' failed` {
    val xs = collection.mutable.IndexedSeq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " was equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " was equal to 2")
  }
  def `collection.mutable.IndexedSeq(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should be less than comparison' failed` {
    val xs = collection.mutable.IndexedSeq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be < 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThanEqual(xs, 2)) + ", " + getFirstMoreThanEqual(xs, 2) + " was not less than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThanEqual(xs, 2) + " was not less than 2")
  }
  def `collection.mutable.IndexedSeq(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not be less than comparison' failed` {
    val xs = collection.mutable.IndexedSeq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be < (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThan(xs, 2)) + ", " + getFirstLessThan(xs, 2) + " was less than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThan(xs, 2) + " was less than 2")
  }
  def `collection.mutable.IndexedSeq(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should be less than or equal comparison' failed` {
    val xs = collection.mutable.IndexedSeq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be <= 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThan(xs, 2)) + ", " + getFirstMoreThan(xs, 2) + " was not less than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThan(xs, 2) + " was not less than or equal to 2")
  }
  def `collection.mutable.IndexedSeq(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not be less than or equal comparison' failed` {
    val xs = collection.mutable.IndexedSeq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be <= (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThanEqual(xs, 2)) + ", " + getFirstLessThanEqual(xs, 2) + " was less than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThanEqual(xs, 2) + " was less than or equal to 2")
  }
  def `collection.mutable.IndexedSeq(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should be greater than comparison' failed` {
    val xs = collection.mutable.IndexedSeq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be > 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThanEqual(xs, 2)) + ", " + getFirstLessThanEqual(xs, 2) + " was not greater than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThanEqual(xs, 2) + " was not greater than 2")
  }
  def `collection.mutable.IndexedSeq(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not be greater than comparison' failed` {
    val xs = collection.mutable.IndexedSeq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be > (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThan(xs, 2)) + ", " + getFirstMoreThan(xs, 2) + " was greater than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThan(xs, 2) + " was greater than 2")
  }
  def `collection.mutable.IndexedSeq(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should be greater than or equal comparison' failed` {
    val xs = collection.mutable.IndexedSeq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be >= 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThan(xs, 2)) + ", " + getFirstLessThan(xs, 2) + " was not greater than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThan(xs, 2) + " was not greater than or equal to 2")
  }
  def `collection.mutable.IndexedSeq(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not be greater than or equal comparison' failed` {
    val xs = collection.mutable.IndexedSeq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be >= (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThanEqual(xs, 2)) + ", " + getFirstMoreThanEqual(xs, 2) + " was greater than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThanEqual(xs, 2) + " was greater than or equal to 2")
  }
  def `collection.mutable.IndexedSeq(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should be ===' failed` {
    val xs = collection.mutable.IndexedSeq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be === 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[Int](xs, 2)) + ", " + getFirstNotEqual[Int](xs, 2) + " was not equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstNotEqual[Int](xs, 2) + " was not equal to 2")
  }
  def `collection.mutable.IndexedSeq(1, 2, 3) should throw TestFailedException with correct stack depth and message when 'should not be ===' failed` {
    val xs = collection.mutable.IndexedSeq(1, 2, 3)
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be === (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " was equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " was equal to 2")
  }
  def `collection.mutable.Set(1, 2, 3).par should throw TestFailedException with correct stack depth and message when at least one element failed` {
    val xs = collection.mutable.Set(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not equal 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " equaled 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " equaled 2")
  }
  def `collection.mutable.Set(1, 2, 3).par should throw TestFailedException with correct stack depth and message when more than one element failed` {
    val xs = collection.mutable.Set(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be < 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThanEqual(xs, 2)) + ", " + getFirstMoreThanEqual(xs, 2) + " was not less than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThanEqual(xs, 2) + " was not less than 2")
  }
  def `collection.mutable.Set(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should equal' failed` {
    val xs = collection.mutable.Set(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should equal (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[Int](xs, 2)) + ", " + getFirstNotEqual[Int](xs, 2) + " did not equal 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstNotEqual[Int](xs, 2) + " did not equal 2")
  }
  def `collection.mutable.Set(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should not equal' failed` {
    val xs = collection.mutable.Set(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not equal 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " equaled 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " equaled 2")
  }
  def `collection.mutable.Set(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should be' failed` {
    val xs = collection.mutable.Set(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[Int](xs, 2)) + ", " + getFirstNotEqual[Int](xs, 2) + " was not equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstNotEqual[Int](xs, 2) + " was not equal to 2")
  }
  def `collection.mutable.Set(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should not be' failed` {
    val xs = collection.mutable.Set(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " was equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " was equal to 2")
  }
  def `collection.mutable.Set(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should be less than comparison' failed` {
    val xs = collection.mutable.Set(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be < 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThanEqual(xs, 2)) + ", " + getFirstMoreThanEqual(xs, 2) + " was not less than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThanEqual(xs, 2) + " was not less than 2")
  }
  def `collection.mutable.Set(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should not be less than comparison' failed` {
    val xs = collection.mutable.Set(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be < (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThan(xs, 2)) + ", " + getFirstLessThan(xs, 2) + " was less than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThan(xs, 2) + " was less than 2")
  }
  def `collection.mutable.Set(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should be less than or equal comparison' failed` {
    val xs = collection.mutable.Set(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be <= 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThan(xs, 2)) + ", " + getFirstMoreThan(xs, 2) + " was not less than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThan(xs, 2) + " was not less than or equal to 2")
  }
  def `collection.mutable.Set(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should not be less than or equal comparison' failed` {
    val xs = collection.mutable.Set(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be <= (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThanEqual(xs, 2)) + ", " + getFirstLessThanEqual(xs, 2) + " was less than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThanEqual(xs, 2) + " was less than or equal to 2")
  }
  def `collection.mutable.Set(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should be greater than comparison' failed` {
    val xs = collection.mutable.Set(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be > 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThanEqual(xs, 2)) + ", " + getFirstLessThanEqual(xs, 2) + " was not greater than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThanEqual(xs, 2) + " was not greater than 2")
  }
  def `collection.mutable.Set(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should not be greater than comparison' failed` {
    val xs = collection.mutable.Set(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be > (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThan(xs, 2)) + ", " + getFirstMoreThan(xs, 2) + " was greater than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThan(xs, 2) + " was greater than 2")
  }
  def `collection.mutable.Set(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should be greater than or equal comparison' failed` {
    val xs = collection.mutable.Set(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be >= 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThan(xs, 2)) + ", " + getFirstLessThan(xs, 2) + " was not greater than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThan(xs, 2) + " was not greater than or equal to 2")
  }
  def `collection.mutable.Set(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should not be greater than or equal comparison' failed` {
    val xs = collection.mutable.Set(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be >= (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThanEqual(xs, 2)) + ", " + getFirstMoreThanEqual(xs, 2) + " was greater than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThanEqual(xs, 2) + " was greater than or equal to 2")
  }
  def `collection.mutable.Set(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should be ===' failed` {
    val xs = collection.mutable.Set(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be === 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[Int](xs, 2)) + ", " + getFirstNotEqual[Int](xs, 2) + " was not equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstNotEqual[Int](xs, 2) + " was not equal to 2")
  }
  def `collection.mutable.Set(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should not be ===' failed` {
    val xs = collection.mutable.Set(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be === (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " was equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " was equal to 2")
  }
  def `(new collection.mutable.ListBuffer() ++ List(1, 2, 3)).par should throw TestFailedException with correct stack depth and message when at least one element failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(1, 2, 3)).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not equal 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " equaled 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " equaled 2")
  }
  def `(new collection.mutable.ListBuffer() ++ List(1, 2, 3)).par should throw TestFailedException with correct stack depth and message when more than one element failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(1, 2, 3)).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be < 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThanEqual(xs, 2)) + ", " + getFirstMoreThanEqual(xs, 2) + " was not less than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThanEqual(xs, 2) + " was not less than 2")
  }
  def `(new collection.mutable.ListBuffer() ++ List(1, 2, 3)).par should throw TestFailedException with correct stack depth and message when 'should equal' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(1, 2, 3)).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should equal (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[Int](xs, 2)) + ", " + getFirstNotEqual[Int](xs, 2) + " did not equal 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstNotEqual[Int](xs, 2) + " did not equal 2")
  }
  def `(new collection.mutable.ListBuffer() ++ List(1, 2, 3)).par should throw TestFailedException with correct stack depth and message when 'should not equal' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(1, 2, 3)).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not equal 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " equaled 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " equaled 2")
  }
  def `(new collection.mutable.ListBuffer() ++ List(1, 2, 3)).par should throw TestFailedException with correct stack depth and message when 'should be' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(1, 2, 3)).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[Int](xs, 2)) + ", " + getFirstNotEqual[Int](xs, 2) + " was not equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstNotEqual[Int](xs, 2) + " was not equal to 2")
  }
  def `(new collection.mutable.ListBuffer() ++ List(1, 2, 3)).par should throw TestFailedException with correct stack depth and message when 'should not be' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(1, 2, 3)).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " was equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " was equal to 2")
  }
  def `(new collection.mutable.ListBuffer() ++ List(1, 2, 3)).par should throw TestFailedException with correct stack depth and message when 'should be less than comparison' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(1, 2, 3)).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be < 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThanEqual(xs, 2)) + ", " + getFirstMoreThanEqual(xs, 2) + " was not less than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThanEqual(xs, 2) + " was not less than 2")
  }
  def `(new collection.mutable.ListBuffer() ++ List(1, 2, 3)).par should throw TestFailedException with correct stack depth and message when 'should not be less than comparison' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(1, 2, 3)).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be < (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThan(xs, 2)) + ", " + getFirstLessThan(xs, 2) + " was less than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThan(xs, 2) + " was less than 2")
  }
  def `(new collection.mutable.ListBuffer() ++ List(1, 2, 3)).par should throw TestFailedException with correct stack depth and message when 'should be less than or equal comparison' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(1, 2, 3)).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be <= 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThan(xs, 2)) + ", " + getFirstMoreThan(xs, 2) + " was not less than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThan(xs, 2) + " was not less than or equal to 2")
  }
  def `(new collection.mutable.ListBuffer() ++ List(1, 2, 3)).par should throw TestFailedException with correct stack depth and message when 'should not be less than or equal comparison' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(1, 2, 3)).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be <= (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThanEqual(xs, 2)) + ", " + getFirstLessThanEqual(xs, 2) + " was less than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThanEqual(xs, 2) + " was less than or equal to 2")
  }
  def `(new collection.mutable.ListBuffer() ++ List(1, 2, 3)).par should throw TestFailedException with correct stack depth and message when 'should be greater than comparison' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(1, 2, 3)).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be > 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThanEqual(xs, 2)) + ", " + getFirstLessThanEqual(xs, 2) + " was not greater than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThanEqual(xs, 2) + " was not greater than 2")
  }
  def `(new collection.mutable.ListBuffer() ++ List(1, 2, 3)).par should throw TestFailedException with correct stack depth and message when 'should not be greater than comparison' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(1, 2, 3)).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be > (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThan(xs, 2)) + ", " + getFirstMoreThan(xs, 2) + " was greater than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThan(xs, 2) + " was greater than 2")
  }
  def `(new collection.mutable.ListBuffer() ++ List(1, 2, 3)).par should throw TestFailedException with correct stack depth and message when 'should be greater than or equal comparison' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(1, 2, 3)).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be >= 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThan(xs, 2)) + ", " + getFirstLessThan(xs, 2) + " was not greater than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThan(xs, 2) + " was not greater than or equal to 2")
  }
  def `(new collection.mutable.ListBuffer() ++ List(1, 2, 3)).par should throw TestFailedException with correct stack depth and message when 'should not be greater than or equal comparison' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(1, 2, 3)).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be >= (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThanEqual(xs, 2)) + ", " + getFirstMoreThanEqual(xs, 2) + " was greater than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThanEqual(xs, 2) + " was greater than or equal to 2")
  }
  def `(new collection.mutable.ListBuffer() ++ List(1, 2, 3)).par should throw TestFailedException with correct stack depth and message when 'should be ===' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(1, 2, 3)).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be === 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[Int](xs, 2)) + ", " + getFirstNotEqual[Int](xs, 2) + " was not equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstNotEqual[Int](xs, 2) + " was not equal to 2")
  }
  def `(new collection.mutable.ListBuffer() ++ List(1, 2, 3)).par should throw TestFailedException with correct stack depth and message when 'should not be ===' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List(1, 2, 3)).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be === (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " was equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " was equal to 2")
  }
  def `collection.mutable.Seq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when at least one element failed` {
    val xs = collection.mutable.Seq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not equal 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " equaled 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " equaled 2")
  }
  def `collection.mutable.Seq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when more than one element failed` {
    val xs = collection.mutable.Seq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be < 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThanEqual(xs, 2)) + ", " + getFirstMoreThanEqual(xs, 2) + " was not less than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThanEqual(xs, 2) + " was not less than 2")
  }
  def `collection.mutable.Seq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should equal' failed` {
    val xs = collection.mutable.Seq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should equal (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[Int](xs, 2)) + ", " + getFirstNotEqual[Int](xs, 2) + " did not equal 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstNotEqual[Int](xs, 2) + " did not equal 2")
  }
  def `collection.mutable.Seq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should not equal' failed` {
    val xs = collection.mutable.Seq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not equal 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " equaled 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " equaled 2")
  }
  def `collection.mutable.Seq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should be' failed` {
    val xs = collection.mutable.Seq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[Int](xs, 2)) + ", " + getFirstNotEqual[Int](xs, 2) + " was not equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstNotEqual[Int](xs, 2) + " was not equal to 2")
  }
  def `collection.mutable.Seq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should not be' failed` {
    val xs = collection.mutable.Seq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " was equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " was equal to 2")
  }
  def `collection.mutable.Seq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should be less than comparison' failed` {
    val xs = collection.mutable.Seq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be < 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThanEqual(xs, 2)) + ", " + getFirstMoreThanEqual(xs, 2) + " was not less than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThanEqual(xs, 2) + " was not less than 2")
  }
  def `collection.mutable.Seq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should not be less than comparison' failed` {
    val xs = collection.mutable.Seq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be < (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThan(xs, 2)) + ", " + getFirstLessThan(xs, 2) + " was less than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThan(xs, 2) + " was less than 2")
  }
  def `collection.mutable.Seq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should be less than or equal comparison' failed` {
    val xs = collection.mutable.Seq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be <= 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThan(xs, 2)) + ", " + getFirstMoreThan(xs, 2) + " was not less than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThan(xs, 2) + " was not less than or equal to 2")
  }
  def `collection.mutable.Seq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should not be less than or equal comparison' failed` {
    val xs = collection.mutable.Seq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be <= (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThanEqual(xs, 2)) + ", " + getFirstLessThanEqual(xs, 2) + " was less than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThanEqual(xs, 2) + " was less than or equal to 2")
  }
  def `collection.mutable.Seq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should be greater than comparison' failed` {
    val xs = collection.mutable.Seq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be > 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThanEqual(xs, 2)) + ", " + getFirstLessThanEqual(xs, 2) + " was not greater than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThanEqual(xs, 2) + " was not greater than 2")
  }
  def `collection.mutable.Seq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should not be greater than comparison' failed` {
    val xs = collection.mutable.Seq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be > (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThan(xs, 2)) + ", " + getFirstMoreThan(xs, 2) + " was greater than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThan(xs, 2) + " was greater than 2")
  }
  def `collection.mutable.Seq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should be greater than or equal comparison' failed` {
    val xs = collection.mutable.Seq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be >= 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThan(xs, 2)) + ", " + getFirstLessThan(xs, 2) + " was not greater than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThan(xs, 2) + " was not greater than or equal to 2")
  }
  def `collection.mutable.Seq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should not be greater than or equal comparison' failed` {
    val xs = collection.mutable.Seq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be >= (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThanEqual(xs, 2)) + ", " + getFirstMoreThanEqual(xs, 2) + " was greater than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThanEqual(xs, 2) + " was greater than or equal to 2")
  }
  def `collection.mutable.Seq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should be ===' failed` {
    val xs = collection.mutable.Seq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be === 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[Int](xs, 2)) + ", " + getFirstNotEqual[Int](xs, 2) + " was not equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstNotEqual[Int](xs, 2) + " was not equal to 2")
  }
  def `collection.mutable.Seq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should not be ===' failed` {
    val xs = collection.mutable.Seq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be === (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " was equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " was equal to 2")
  }
  def `collection.mutable.IndexedSeq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when at least one element failed` {
    val xs = collection.mutable.IndexedSeq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not equal 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " equaled 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " equaled 2")
  }
  def `collection.mutable.IndexedSeq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when more than one element failed` {
    val xs = collection.mutable.IndexedSeq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be < 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThanEqual(xs, 2)) + ", " + getFirstMoreThanEqual(xs, 2) + " was not less than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThanEqual(xs, 2) + " was not less than 2")
  }
  def `collection.mutable.IndexedSeq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should equal' failed` {
    val xs = collection.mutable.IndexedSeq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should equal (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[Int](xs, 2)) + ", " + getFirstNotEqual[Int](xs, 2) + " did not equal 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstNotEqual[Int](xs, 2) + " did not equal 2")
  }
  def `collection.mutable.IndexedSeq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should not equal' failed` {
    val xs = collection.mutable.IndexedSeq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not equal 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " equaled 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " equaled 2")
  }
  def `collection.mutable.IndexedSeq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should be' failed` {
    val xs = collection.mutable.IndexedSeq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[Int](xs, 2)) + ", " + getFirstNotEqual[Int](xs, 2) + " was not equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstNotEqual[Int](xs, 2) + " was not equal to 2")
  }
  def `collection.mutable.IndexedSeq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should not be' failed` {
    val xs = collection.mutable.IndexedSeq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " was equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " was equal to 2")
  }
  def `collection.mutable.IndexedSeq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should be less than comparison' failed` {
    val xs = collection.mutable.IndexedSeq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be < 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThanEqual(xs, 2)) + ", " + getFirstMoreThanEqual(xs, 2) + " was not less than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThanEqual(xs, 2) + " was not less than 2")
  }
  def `collection.mutable.IndexedSeq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should not be less than comparison' failed` {
    val xs = collection.mutable.IndexedSeq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be < (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThan(xs, 2)) + ", " + getFirstLessThan(xs, 2) + " was less than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThan(xs, 2) + " was less than 2")
  }
  def `collection.mutable.IndexedSeq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should be less than or equal comparison' failed` {
    val xs = collection.mutable.IndexedSeq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be <= 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThan(xs, 2)) + ", " + getFirstMoreThan(xs, 2) + " was not less than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThan(xs, 2) + " was not less than or equal to 2")
  }
  def `collection.mutable.IndexedSeq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should not be less than or equal comparison' failed` {
    val xs = collection.mutable.IndexedSeq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be <= (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThanEqual(xs, 2)) + ", " + getFirstLessThanEqual(xs, 2) + " was less than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThanEqual(xs, 2) + " was less than or equal to 2")
  }
  def `collection.mutable.IndexedSeq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should be greater than comparison' failed` {
    val xs = collection.mutable.IndexedSeq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be > 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThanEqual(xs, 2)) + ", " + getFirstLessThanEqual(xs, 2) + " was not greater than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThanEqual(xs, 2) + " was not greater than 2")
  }
  def `collection.mutable.IndexedSeq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should not be greater than comparison' failed` {
    val xs = collection.mutable.IndexedSeq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be > (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThan(xs, 2)) + ", " + getFirstMoreThan(xs, 2) + " was greater than 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThan(xs, 2) + " was greater than 2")
  }
  def `collection.mutable.IndexedSeq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should be greater than or equal comparison' failed` {
    val xs = collection.mutable.IndexedSeq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be >= 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLessThan(xs, 2)) + ", " + getFirstLessThan(xs, 2) + " was not greater than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstLessThan(xs, 2) + " was not greater than or equal to 2")
  }
  def `collection.mutable.IndexedSeq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should not be greater than or equal comparison' failed` {
    val xs = collection.mutable.IndexedSeq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be >= (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstMoreThanEqual(xs, 2)) + ", " + getFirstMoreThanEqual(xs, 2) + " was greater than or equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstMoreThanEqual(xs, 2) + " was greater than or equal to 2")
  }
  def `collection.mutable.IndexedSeq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should be ===' failed` {
    val xs = collection.mutable.IndexedSeq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be === 2
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[Int](xs, 2)) + ", " + getFirstNotEqual[Int](xs, 2) + " was not equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstNotEqual[Int](xs, 2) + " was not equal to 2")
  }
  def `collection.mutable.IndexedSeq(1, 2, 3).par should throw TestFailedException with correct stack depth and message when 'should not be ===' failed` {
    val xs = collection.mutable.IndexedSeq(1, 2, 3).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be === (2)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[Int](xs, 2)) + ", " + getFirstEqual[Int](xs, 2) + " was equal to 2 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "" + getFirstEqual[Int](xs, 2) + " was equal to 2")
  }
  def `Set("1", null, "3") should throw TestFailedException with correct stack depth and message when 'should be null' failed` {
    val xs = Set("1", null, "3")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be (null)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[String](xs, null)) + ", \"" + getFirstNotEqual[String](xs, null) + "\" was not null (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstNotEqual[String](xs, null) + "\" was not null")
  }
  def `Set("1", null, "3") should throw TestFailedException with correct stack depth and message when 'should not be null' failed` {
    val xs = Set("1", null, "3")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be null
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[String](xs, null)) + ", The reference was null (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "The reference was null")
  }
  def `List("1", null, "3") should throw TestFailedException with correct stack depth and message when 'should be null' failed` {
    val xs = List("1", null, "3")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be (null)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[String](xs, null)) + ", \"" + getFirstNotEqual[String](xs, null) + "\" was not null (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstNotEqual[String](xs, null) + "\" was not null")
  }
  def `List("1", null, "3") should throw TestFailedException with correct stack depth and message when 'should not be null' failed` {
    val xs = List("1", null, "3")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be null
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[String](xs, null)) + ", The reference was null (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "The reference was null")
  }
  def `Seq("1", null, "3") should throw TestFailedException with correct stack depth and message when 'should be null' failed` {
    val xs = Seq("1", null, "3")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be (null)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[String](xs, null)) + ", \"" + getFirstNotEqual[String](xs, null) + "\" was not null (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstNotEqual[String](xs, null) + "\" was not null")
  }
  def `Seq("1", null, "3") should throw TestFailedException with correct stack depth and message when 'should not be null' failed` {
    val xs = Seq("1", null, "3")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be null
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[String](xs, null)) + ", The reference was null (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "The reference was null")
  }
  def `Array("1", null, "3") should throw TestFailedException with correct stack depth and message when 'should be null' failed` {
    val xs = Array("1", null, "3")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be (null)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[String](xs, null)) + ", \"" + getFirstNotEqual[String](xs, null) + "\" was not null (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + "WrappedArray(1, null, 3)", "\"" + getFirstNotEqual[String](xs, null) + "\" was not null")
  }
  def `Array("1", null, "3") should throw TestFailedException with correct stack depth and message when 'should not be null' failed` {
    val xs = Array("1", null, "3")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be null
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[String](xs, null)) + ", The reference was null (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + "WrappedArray(1, null, 3)", "The reference was null")
  }
  def `IndexedSeq("1", null, "3") should throw TestFailedException with correct stack depth and message when 'should be null' failed` {
    val xs = IndexedSeq("1", null, "3")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be (null)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[String](xs, null)) + ", \"" + getFirstNotEqual[String](xs, null) + "\" was not null (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstNotEqual[String](xs, null) + "\" was not null")
  }
  def `IndexedSeq("1", null, "3") should throw TestFailedException with correct stack depth and message when 'should not be null' failed` {
    val xs = IndexedSeq("1", null, "3")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be null
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[String](xs, null)) + ", The reference was null (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "The reference was null")
  }
  def `Vector("1", null, "3") should throw TestFailedException with correct stack depth and message when 'should be null' failed` {
    val xs = Vector("1", null, "3")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be (null)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[String](xs, null)) + ", \"" + getFirstNotEqual[String](xs, null) + "\" was not null (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstNotEqual[String](xs, null) + "\" was not null")
  }
  def `Vector("1", null, "3") should throw TestFailedException with correct stack depth and message when 'should not be null' failed` {
    val xs = Vector("1", null, "3")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be null
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[String](xs, null)) + ", The reference was null (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "The reference was null")
  }
  def `Set("1", null, "3").par should throw TestFailedException with correct stack depth and message when 'should be null' failed` {
    val xs = Set("1", null, "3").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be (null)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[String](xs, null)) + ", \"" + getFirstNotEqual[String](xs, null) + "\" was not null (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstNotEqual[String](xs, null) + "\" was not null")
  }
  def `Set("1", null, "3").par should throw TestFailedException with correct stack depth and message when 'should not be null' failed` {
    val xs = Set("1", null, "3").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be null
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[String](xs, null)) + ", The reference was null (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "The reference was null")
  }
  def `List("1", null, "3").par should throw TestFailedException with correct stack depth and message when 'should be null' failed` {
    val xs = List("1", null, "3").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be (null)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[String](xs, null)) + ", \"" + getFirstNotEqual[String](xs, null) + "\" was not null (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstNotEqual[String](xs, null) + "\" was not null")
  }
  def `List("1", null, "3").par should throw TestFailedException with correct stack depth and message when 'should not be null' failed` {
    val xs = List("1", null, "3").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be null
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[String](xs, null)) + ", The reference was null (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "The reference was null")
  }
  def `Seq("1", null, "3").par should throw TestFailedException with correct stack depth and message when 'should be null' failed` {
    val xs = Seq("1", null, "3").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be (null)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[String](xs, null)) + ", \"" + getFirstNotEqual[String](xs, null) + "\" was not null (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstNotEqual[String](xs, null) + "\" was not null")
  }
  def `Seq("1", null, "3").par should throw TestFailedException with correct stack depth and message when 'should not be null' failed` {
    val xs = Seq("1", null, "3").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be null
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[String](xs, null)) + ", The reference was null (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "The reference was null")
  }
  def `IndexedSeq("1", null, "3").par should throw TestFailedException with correct stack depth and message when 'should be null' failed` {
    val xs = IndexedSeq("1", null, "3").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be (null)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[String](xs, null)) + ", \"" + getFirstNotEqual[String](xs, null) + "\" was not null (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstNotEqual[String](xs, null) + "\" was not null")
  }
  def `IndexedSeq("1", null, "3").par should throw TestFailedException with correct stack depth and message when 'should not be null' failed` {
    val xs = IndexedSeq("1", null, "3").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be null
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[String](xs, null)) + ", The reference was null (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "The reference was null")
  }
  def `new collection.mutable.ListBuffer() ++ List("1", null, "3") should throw TestFailedException with correct stack depth and message when 'should be null' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List("1", null, "3")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be (null)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[String](xs, null)) + ", \"" + getFirstNotEqual[String](xs, null) + "\" was not null (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstNotEqual[String](xs, null) + "\" was not null")
  }
  def `new collection.mutable.ListBuffer() ++ List("1", null, "3") should throw TestFailedException with correct stack depth and message when 'should not be null' failed` {
    val xs = new collection.mutable.ListBuffer() ++ List("1", null, "3")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be null
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[String](xs, null)) + ", The reference was null (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "The reference was null")
  }
  def `collection.mutable.Seq("1", null, "3") should throw TestFailedException with correct stack depth and message when 'should be null' failed` {
    val xs = collection.mutable.Seq("1", null, "3")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be (null)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[String](xs, null)) + ", \"" + getFirstNotEqual[String](xs, null) + "\" was not null (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstNotEqual[String](xs, null) + "\" was not null")
  }
  def `collection.mutable.Seq("1", null, "3") should throw TestFailedException with correct stack depth and message when 'should not be null' failed` {
    val xs = collection.mutable.Seq("1", null, "3")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be null
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[String](xs, null)) + ", The reference was null (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "The reference was null")
  }
  def `collection.mutable.IndexedSeq("1", null, "3") should throw TestFailedException with correct stack depth and message when 'should be null' failed` {
    val xs = collection.mutable.IndexedSeq("1", null, "3")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be (null)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[String](xs, null)) + ", \"" + getFirstNotEqual[String](xs, null) + "\" was not null (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstNotEqual[String](xs, null) + "\" was not null")
  }
  def `collection.mutable.IndexedSeq("1", null, "3") should throw TestFailedException with correct stack depth and message when 'should not be null' failed` {
    val xs = collection.mutable.IndexedSeq("1", null, "3")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be null
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[String](xs, null)) + ", The reference was null (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "The reference was null")
  }
  def `(new collection.mutable.ListBuffer() ++ List("1", null, "3")).par should throw TestFailedException with correct stack depth and message when 'should be null' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List("1", null, "3")).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be (null)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[String](xs, null)) + ", \"" + getFirstNotEqual[String](xs, null) + "\" was not null (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstNotEqual[String](xs, null) + "\" was not null")
  }
  def `(new collection.mutable.ListBuffer() ++ List("1", null, "3")).par should throw TestFailedException with correct stack depth and message when 'should not be null' failed` {
    val xs = (new collection.mutable.ListBuffer() ++ List("1", null, "3")).par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be null
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[String](xs, null)) + ", The reference was null (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "The reference was null")
  }
  def `collection.mutable.Seq("1", null, "3").par should throw TestFailedException with correct stack depth and message when 'should be null' failed` {
    val xs = collection.mutable.Seq("1", null, "3").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be (null)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[String](xs, null)) + ", \"" + getFirstNotEqual[String](xs, null) + "\" was not null (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstNotEqual[String](xs, null) + "\" was not null")
  }
  def `collection.mutable.Seq("1", null, "3").par should throw TestFailedException with correct stack depth and message when 'should not be null' failed` {
    val xs = collection.mutable.Seq("1", null, "3").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be null
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[String](xs, null)) + ", The reference was null (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "The reference was null")
  }
  def `collection.mutable.IndexedSeq("1", null, "3").par should throw TestFailedException with correct stack depth and message when 'should be null' failed` {
    val xs = collection.mutable.IndexedSeq("1", null, "3").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be (null)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstNotEqual[String](xs, null)) + ", \"" + getFirstNotEqual[String](xs, null) + "\" was not null (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstNotEqual[String](xs, null) + "\" was not null")
  }
  def `collection.mutable.IndexedSeq("1", null, "3").par should throw TestFailedException with correct stack depth and message when 'should not be null' failed` {
    val xs = collection.mutable.IndexedSeq("1", null, "3").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be null
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstEqual[String](xs, null)) + ", The reference was null (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "The reference was null")
  }
  def `Set("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should be symbol' failed` {
    val xs = Set("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsNotEmpty(xs, "")) + ", \"" + getFirstIsNotEmpty(xs, "") + "\" was not empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsNotEmpty(xs, "") + "\" was not empty")
  }
  def `Set("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should not be symbol' failed` {
    val xs = Set("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsEmpty(xs, "")) + ", \"" + getFirstIsEmpty(xs, "") + "\" was empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsEmpty(xs, "") + "\" was empty")
  }
  def `Set("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should be property' failed` {
    val xs = Set("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be (empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsNotEmpty(xs, "")) + ", \"" + getFirstIsNotEmpty(xs, "") + "\" was not empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsNotEmpty(xs, "") + "\" was not empty")
  }
  def `Set("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should not be property' failed` {
    val xs = Set("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsEmpty(xs, "")) + ", \"" + getFirstIsEmpty(xs, "") + "\" was empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsEmpty(xs, "") + "\" was empty")
  }
  def `Set("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should be a symbol' failed` {
    val xs = Set("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be a 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsNotEmpty(xs, "")) + ", \"" + getFirstIsNotEmpty(xs, "") + "\" was not a empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsNotEmpty(xs, "") + "\" was not a empty")
  }
  def `Set("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should not be a symbol' failed` {
    val xs = Set("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be a ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsEmpty(xs, "")) + ", \"" + getFirstIsEmpty(xs, "") + "\" was a empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsEmpty(xs, "") + "\" was a empty")
  }
  def `Set("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should be a property' failed` {
    val xs = Set("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be a empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsNotEmpty(xs, "")) + ", \"" + getFirstIsNotEmpty(xs, "") + "\" was not a empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsNotEmpty(xs, "") + "\" was not a empty")
  }
  def `Set("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should not be a property' failed` {
    val xs = Set("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be a (empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsEmpty(xs, "")) + ", \"" + getFirstIsEmpty(xs, "") + "\" was a empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsEmpty(xs, "") + "\" was a empty")
  }
  def `Set("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should be an symbol' failed` {
    val xs = Set("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be an 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsNotEmpty(xs, "")) + ", \"" + getFirstIsNotEmpty(xs, "") + "\" was not an empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsNotEmpty(xs, "") + "\" was not an empty")
  }
  def `Set("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should not be an symbol' failed` {
    val xs = Set("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be an ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsEmpty(xs, "")) + ", \"" + getFirstIsEmpty(xs, "") + "\" was an empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsEmpty(xs, "") + "\" was an empty")
  }
  def `Set("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should be an property' failed` {
    val xs = Set("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be an empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsNotEmpty(xs, "")) + ", \"" + getFirstIsNotEmpty(xs, "") + "\" was not an empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsNotEmpty(xs, "") + "\" was not an empty")
  }
  def `Set("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should not be an property' failed` {
    val xs = Set("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be an (empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsEmpty(xs, "")) + ", \"" + getFirstIsEmpty(xs, "") + "\" was an empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsEmpty(xs, "") + "\" was an empty")
  }
  def `Set("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should have property' failed` {
    val xs = Set("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have (plength(0))
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLengthNotEqualLength(xs, 0)) + ", The length property had value " + getFirstLengthNotEqualLength(xs, 0).length + ", instead of its expected value 0, on object \"" + getFirstLengthNotEqualLength(xs, 0) + "\" (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "The length property had value " + getFirstLengthNotEqualLength(xs, 0).length + ", instead of its expected value 0, on object \"" + getFirstLengthNotEqualLength(xs, 0) + "\"")
  }
  def `Set("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should not have property' failed` {
    val xs = Set("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have plength(0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLengthEqual(xs, 0)) + ", The length property had its expected value 0, on object \"" + getFirstLengthEqual(xs, 0) + "\" (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "The length property had its expected value 0, on object \"" + getFirstLengthEqual(xs, 0) + "\"")
  }
  def `Set("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should have length' failed` {
    val xs = Set("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLengthNotEqual(xs, 0)) + ", \"" + getFirstLengthNotEqual(xs, 0) + "\" did not have length 0 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstLengthNotEqual(xs, 0) + "\" did not have length 0")
  }
  def `Set("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should not have length' failed` {
    val xs = Set("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLengthEqual(xs, 0)) + ", \"" + getFirstLengthEqual(xs, 0) + "\" had length 0 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstLengthEqual(xs, 0) + "\" had length 0")
  }
  def `Set("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should have size' failed` {
    val xs = Set("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstSizeNotEqual(xs, 0)) + ", \"" + getFirstSizeNotEqual(xs, 0) + "\" did not have size 0 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstSizeNotEqual(xs, 0) + "\" did not have size 0")
  }
  def `Set("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should not have size' failed` {
    val xs = Set("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstSizeEqual(xs, 0)) + ", \"" + getFirstSizeEqual(xs, 0) + "\" had size 0 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstSizeEqual(xs, 0) + "\" had size 0")
  }
  def `List("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should be symbol' failed` {
    val xs = List("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsNotEmpty(xs, "")) + ", \"" + getFirstIsNotEmpty(xs, "") + "\" was not empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsNotEmpty(xs, "") + "\" was not empty")
  }
  def `List("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should not be symbol' failed` {
    val xs = List("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsEmpty(xs, "")) + ", \"" + getFirstIsEmpty(xs, "") + "\" was empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsEmpty(xs, "") + "\" was empty")
  }
  def `List("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should be property' failed` {
    val xs = List("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be (empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsNotEmpty(xs, "")) + ", \"" + getFirstIsNotEmpty(xs, "") + "\" was not empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsNotEmpty(xs, "") + "\" was not empty")
  }
  def `List("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should not be property' failed` {
    val xs = List("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsEmpty(xs, "")) + ", \"" + getFirstIsEmpty(xs, "") + "\" was empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsEmpty(xs, "") + "\" was empty")
  }
  def `List("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should be a symbol' failed` {
    val xs = List("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be a 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsNotEmpty(xs, "")) + ", \"" + getFirstIsNotEmpty(xs, "") + "\" was not a empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsNotEmpty(xs, "") + "\" was not a empty")
  }
  def `List("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should not be a symbol' failed` {
    val xs = List("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be a ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsEmpty(xs, "")) + ", \"" + getFirstIsEmpty(xs, "") + "\" was a empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsEmpty(xs, "") + "\" was a empty")
  }
  def `List("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should be a property' failed` {
    val xs = List("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be a empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsNotEmpty(xs, "")) + ", \"" + getFirstIsNotEmpty(xs, "") + "\" was not a empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsNotEmpty(xs, "") + "\" was not a empty")
  }
  def `List("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should not be a property' failed` {
    val xs = List("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be a (empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsEmpty(xs, "")) + ", \"" + getFirstIsEmpty(xs, "") + "\" was a empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsEmpty(xs, "") + "\" was a empty")
  }
  def `List("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should be an symbol' failed` {
    val xs = List("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be an 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsNotEmpty(xs, "")) + ", \"" + getFirstIsNotEmpty(xs, "") + "\" was not an empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsNotEmpty(xs, "") + "\" was not an empty")
  }
  def `List("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should not be an symbol' failed` {
    val xs = List("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be an ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsEmpty(xs, "")) + ", \"" + getFirstIsEmpty(xs, "") + "\" was an empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsEmpty(xs, "") + "\" was an empty")
  }
  def `List("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should be an property' failed` {
    val xs = List("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be an empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsNotEmpty(xs, "")) + ", \"" + getFirstIsNotEmpty(xs, "") + "\" was not an empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsNotEmpty(xs, "") + "\" was not an empty")
  }
  def `List("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should not be an property' failed` {
    val xs = List("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be an (empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsEmpty(xs, "")) + ", \"" + getFirstIsEmpty(xs, "") + "\" was an empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsEmpty(xs, "") + "\" was an empty")
  }
  def `List("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should have property' failed` {
    val xs = List("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have (plength(0))
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLengthNotEqualLength(xs, 0)) + ", The length property had value " + getFirstLengthNotEqualLength(xs, 0).length + ", instead of its expected value 0, on object \"" + getFirstLengthNotEqualLength(xs, 0) + "\" (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "The length property had value " + getFirstLengthNotEqualLength(xs, 0).length + ", instead of its expected value 0, on object \"" + getFirstLengthNotEqualLength(xs, 0) + "\"")
  }
  def `List("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should not have property' failed` {
    val xs = List("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have plength(0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLengthEqual(xs, 0)) + ", The length property had its expected value 0, on object \"" + getFirstLengthEqual(xs, 0) + "\" (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "The length property had its expected value 0, on object \"" + getFirstLengthEqual(xs, 0) + "\"")
  }
  def `List("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should have length' failed` {
    val xs = List("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLengthNotEqual(xs, 0)) + ", \"" + getFirstLengthNotEqual(xs, 0) + "\" did not have length 0 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstLengthNotEqual(xs, 0) + "\" did not have length 0")
  }
  def `List("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should not have length' failed` {
    val xs = List("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLengthEqual(xs, 0)) + ", \"" + getFirstLengthEqual(xs, 0) + "\" had length 0 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstLengthEqual(xs, 0) + "\" had length 0")
  }
  def `List("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should have size' failed` {
    val xs = List("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstSizeNotEqual(xs, 0)) + ", \"" + getFirstSizeNotEqual(xs, 0) + "\" did not have size 0 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstSizeNotEqual(xs, 0) + "\" did not have size 0")
  }
  def `List("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should not have size' failed` {
    val xs = List("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstSizeEqual(xs, 0)) + ", \"" + getFirstSizeEqual(xs, 0) + "\" had size 0 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstSizeEqual(xs, 0) + "\" had size 0")
  }
  def `Seq("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should be symbol' failed` {
    val xs = Seq("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsNotEmpty(xs, "")) + ", \"" + getFirstIsNotEmpty(xs, "") + "\" was not empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsNotEmpty(xs, "") + "\" was not empty")
  }
  def `Seq("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should not be symbol' failed` {
    val xs = Seq("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsEmpty(xs, "")) + ", \"" + getFirstIsEmpty(xs, "") + "\" was empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsEmpty(xs, "") + "\" was empty")
  }
  def `Seq("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should be property' failed` {
    val xs = Seq("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be (empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsNotEmpty(xs, "")) + ", \"" + getFirstIsNotEmpty(xs, "") + "\" was not empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsNotEmpty(xs, "") + "\" was not empty")
  }
  def `Seq("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should not be property' failed` {
    val xs = Seq("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsEmpty(xs, "")) + ", \"" + getFirstIsEmpty(xs, "") + "\" was empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsEmpty(xs, "") + "\" was empty")
  }
  def `Seq("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should be a symbol' failed` {
    val xs = Seq("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be a 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsNotEmpty(xs, "")) + ", \"" + getFirstIsNotEmpty(xs, "") + "\" was not a empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsNotEmpty(xs, "") + "\" was not a empty")
  }
  def `Seq("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should not be a symbol' failed` {
    val xs = Seq("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be a ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsEmpty(xs, "")) + ", \"" + getFirstIsEmpty(xs, "") + "\" was a empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsEmpty(xs, "") + "\" was a empty")
  }
  def `Seq("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should be a property' failed` {
    val xs = Seq("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be a empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsNotEmpty(xs, "")) + ", \"" + getFirstIsNotEmpty(xs, "") + "\" was not a empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsNotEmpty(xs, "") + "\" was not a empty")
  }
  def `Seq("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should not be a property' failed` {
    val xs = Seq("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be a (empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsEmpty(xs, "")) + ", \"" + getFirstIsEmpty(xs, "") + "\" was a empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsEmpty(xs, "") + "\" was a empty")
  }
  def `Seq("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should be an symbol' failed` {
    val xs = Seq("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be an 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsNotEmpty(xs, "")) + ", \"" + getFirstIsNotEmpty(xs, "") + "\" was not an empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsNotEmpty(xs, "") + "\" was not an empty")
  }
  def `Seq("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should not be an symbol' failed` {
    val xs = Seq("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be an ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsEmpty(xs, "")) + ", \"" + getFirstIsEmpty(xs, "") + "\" was an empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsEmpty(xs, "") + "\" was an empty")
  }
  def `Seq("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should be an property' failed` {
    val xs = Seq("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be an empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsNotEmpty(xs, "")) + ", \"" + getFirstIsNotEmpty(xs, "") + "\" was not an empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsNotEmpty(xs, "") + "\" was not an empty")
  }
  def `Seq("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should not be an property' failed` {
    val xs = Seq("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be an (empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsEmpty(xs, "")) + ", \"" + getFirstIsEmpty(xs, "") + "\" was an empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsEmpty(xs, "") + "\" was an empty")
  }
  def `Seq("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should have property' failed` {
    val xs = Seq("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have (plength(0))
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLengthNotEqualLength(xs, 0)) + ", The length property had value " + getFirstLengthNotEqualLength(xs, 0).length + ", instead of its expected value 0, on object \"" + getFirstLengthNotEqualLength(xs, 0) + "\" (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "The length property had value " + getFirstLengthNotEqualLength(xs, 0).length + ", instead of its expected value 0, on object \"" + getFirstLengthNotEqualLength(xs, 0) + "\"")
  }
  def `Seq("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should not have property' failed` {
    val xs = Seq("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have plength(0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLengthEqual(xs, 0)) + ", The length property had its expected value 0, on object \"" + getFirstLengthEqual(xs, 0) + "\" (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "The length property had its expected value 0, on object \"" + getFirstLengthEqual(xs, 0) + "\"")
  }
  def `Seq("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should have length' failed` {
    val xs = Seq("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLengthNotEqual(xs, 0)) + ", \"" + getFirstLengthNotEqual(xs, 0) + "\" did not have length 0 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstLengthNotEqual(xs, 0) + "\" did not have length 0")
  }
  def `Seq("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should not have length' failed` {
    val xs = Seq("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLengthEqual(xs, 0)) + ", \"" + getFirstLengthEqual(xs, 0) + "\" had length 0 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstLengthEqual(xs, 0) + "\" had length 0")
  }
  def `Seq("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should have size' failed` {
    val xs = Seq("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstSizeNotEqual(xs, 0)) + ", \"" + getFirstSizeNotEqual(xs, 0) + "\" did not have size 0 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstSizeNotEqual(xs, 0) + "\" did not have size 0")
  }
  def `Seq("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should not have size' failed` {
    val xs = Seq("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstSizeEqual(xs, 0)) + ", \"" + getFirstSizeEqual(xs, 0) + "\" had size 0 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstSizeEqual(xs, 0) + "\" had size 0")
  }
  def `Array("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should be symbol' failed` {
    val xs = Array("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsNotEmpty(xs, "")) + ", \"" + getFirstIsNotEmpty(xs, "") + "\" was not empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + "WrappedArray(, boom!, )", "\"" + getFirstIsNotEmpty(xs, "") + "\" was not empty")
  }
  def `Array("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should not be symbol' failed` {
    val xs = Array("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsEmpty(xs, "")) + ", \"" + getFirstIsEmpty(xs, "") + "\" was empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + "WrappedArray(, boom!, )", "\"" + getFirstIsEmpty(xs, "") + "\" was empty")
  }
  def `Array("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should be property' failed` {
    val xs = Array("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be (empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsNotEmpty(xs, "")) + ", \"" + getFirstIsNotEmpty(xs, "") + "\" was not empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + "WrappedArray(, boom!, )", "\"" + getFirstIsNotEmpty(xs, "") + "\" was not empty")
  }
  def `Array("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should not be property' failed` {
    val xs = Array("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsEmpty(xs, "")) + ", \"" + getFirstIsEmpty(xs, "") + "\" was empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + "WrappedArray(, boom!, )", "\"" + getFirstIsEmpty(xs, "") + "\" was empty")
  }
  def `Array("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should be a symbol' failed` {
    val xs = Array("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be a 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsNotEmpty(xs, "")) + ", \"" + getFirstIsNotEmpty(xs, "") + "\" was not a empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + "WrappedArray(, boom!, )", "\"" + getFirstIsNotEmpty(xs, "") + "\" was not a empty")
  }
  def `Array("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should not be a symbol' failed` {
    val xs = Array("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be a ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsEmpty(xs, "")) + ", \"" + getFirstIsEmpty(xs, "") + "\" was a empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + "WrappedArray(, boom!, )", "\"" + getFirstIsEmpty(xs, "") + "\" was a empty")
  }
  def `Array("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should be a property' failed` {
    val xs = Array("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be a empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsNotEmpty(xs, "")) + ", \"" + getFirstIsNotEmpty(xs, "") + "\" was not a empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + "WrappedArray(, boom!, )", "\"" + getFirstIsNotEmpty(xs, "") + "\" was not a empty")
  }
  def `Array("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should not be a property' failed` {
    val xs = Array("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be a (empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsEmpty(xs, "")) + ", \"" + getFirstIsEmpty(xs, "") + "\" was a empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + "WrappedArray(, boom!, )", "\"" + getFirstIsEmpty(xs, "") + "\" was a empty")
  }
  def `Array("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should be an symbol' failed` {
    val xs = Array("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be an 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsNotEmpty(xs, "")) + ", \"" + getFirstIsNotEmpty(xs, "") + "\" was not an empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + "WrappedArray(, boom!, )", "\"" + getFirstIsNotEmpty(xs, "") + "\" was not an empty")
  }
  def `Array("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should not be an symbol' failed` {
    val xs = Array("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be an ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsEmpty(xs, "")) + ", \"" + getFirstIsEmpty(xs, "") + "\" was an empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + "WrappedArray(, boom!, )", "\"" + getFirstIsEmpty(xs, "") + "\" was an empty")
  }
  def `Array("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should be an property' failed` {
    val xs = Array("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be an empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsNotEmpty(xs, "")) + ", \"" + getFirstIsNotEmpty(xs, "") + "\" was not an empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + "WrappedArray(, boom!, )", "\"" + getFirstIsNotEmpty(xs, "") + "\" was not an empty")
  }
  def `Array("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should not be an property' failed` {
    val xs = Array("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be an (empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsEmpty(xs, "")) + ", \"" + getFirstIsEmpty(xs, "") + "\" was an empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + "WrappedArray(, boom!, )", "\"" + getFirstIsEmpty(xs, "") + "\" was an empty")
  }
  def `Array("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should have property' failed` {
    val xs = Array("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have (plength(0))
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLengthNotEqualLength(xs, 0)) + ", The length property had value " + getFirstLengthNotEqualLength(xs, 0).length + ", instead of its expected value 0, on object \"" + getFirstLengthNotEqualLength(xs, 0) + "\" (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + "WrappedArray(, boom!, )", "The length property had value " + getFirstLengthNotEqualLength(xs, 0).length + ", instead of its expected value 0, on object \"" + getFirstLengthNotEqualLength(xs, 0) + "\"")
  }
  def `Array("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should not have property' failed` {
    val xs = Array("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have plength(0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLengthEqual(xs, 0)) + ", The length property had its expected value 0, on object \"" + getFirstLengthEqual(xs, 0) + "\" (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + "WrappedArray(, boom!, )", "The length property had its expected value 0, on object \"" + getFirstLengthEqual(xs, 0) + "\"")
  }
  def `Array("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should have length' failed` {
    val xs = Array("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLengthNotEqual(xs, 0)) + ", \"" + getFirstLengthNotEqual(xs, 0) + "\" did not have length 0 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + "WrappedArray(, boom!, )", "\"" + getFirstLengthNotEqual(xs, 0) + "\" did not have length 0")
  }
  def `Array("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should not have length' failed` {
    val xs = Array("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLengthEqual(xs, 0)) + ", \"" + getFirstLengthEqual(xs, 0) + "\" had length 0 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + "WrappedArray(, boom!, )", "\"" + getFirstLengthEqual(xs, 0) + "\" had length 0")
  }
  def `Array("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should have size' failed` {
    val xs = Array("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstSizeNotEqual(xs, 0)) + ", \"" + getFirstSizeNotEqual(xs, 0) + "\" did not have size 0 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + "WrappedArray(, boom!, )", "\"" + getFirstSizeNotEqual(xs, 0) + "\" did not have size 0")
  }
  def `Array("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should not have size' failed` {
    val xs = Array("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstSizeEqual(xs, 0)) + ", \"" + getFirstSizeEqual(xs, 0) + "\" had size 0 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + "WrappedArray(, boom!, )", "\"" + getFirstSizeEqual(xs, 0) + "\" had size 0")
  }
  def `IndexedSeq("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should be symbol' failed` {
    val xs = IndexedSeq("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsNotEmpty(xs, "")) + ", \"" + getFirstIsNotEmpty(xs, "") + "\" was not empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsNotEmpty(xs, "") + "\" was not empty")
  }
  def `IndexedSeq("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should not be symbol' failed` {
    val xs = IndexedSeq("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsEmpty(xs, "")) + ", \"" + getFirstIsEmpty(xs, "") + "\" was empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsEmpty(xs, "") + "\" was empty")
  }
  def `IndexedSeq("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should be property' failed` {
    val xs = IndexedSeq("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be (empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsNotEmpty(xs, "")) + ", \"" + getFirstIsNotEmpty(xs, "") + "\" was not empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsNotEmpty(xs, "") + "\" was not empty")
  }
  def `IndexedSeq("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should not be property' failed` {
    val xs = IndexedSeq("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsEmpty(xs, "")) + ", \"" + getFirstIsEmpty(xs, "") + "\" was empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsEmpty(xs, "") + "\" was empty")
  }
  def `IndexedSeq("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should be a symbol' failed` {
    val xs = IndexedSeq("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be a 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsNotEmpty(xs, "")) + ", \"" + getFirstIsNotEmpty(xs, "") + "\" was not a empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsNotEmpty(xs, "") + "\" was not a empty")
  }
  def `IndexedSeq("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should not be a symbol' failed` {
    val xs = IndexedSeq("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be a ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsEmpty(xs, "")) + ", \"" + getFirstIsEmpty(xs, "") + "\" was a empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsEmpty(xs, "") + "\" was a empty")
  }
  def `IndexedSeq("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should be a property' failed` {
    val xs = IndexedSeq("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be a empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsNotEmpty(xs, "")) + ", \"" + getFirstIsNotEmpty(xs, "") + "\" was not a empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsNotEmpty(xs, "") + "\" was not a empty")
  }
  def `IndexedSeq("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should not be a property' failed` {
    val xs = IndexedSeq("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be a (empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsEmpty(xs, "")) + ", \"" + getFirstIsEmpty(xs, "") + "\" was a empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsEmpty(xs, "") + "\" was a empty")
  }
  def `IndexedSeq("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should be an symbol' failed` {
    val xs = IndexedSeq("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be an 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsNotEmpty(xs, "")) + ", \"" + getFirstIsNotEmpty(xs, "") + "\" was not an empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsNotEmpty(xs, "") + "\" was not an empty")
  }
  def `IndexedSeq("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should not be an symbol' failed` {
    val xs = IndexedSeq("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be an ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsEmpty(xs, "")) + ", \"" + getFirstIsEmpty(xs, "") + "\" was an empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsEmpty(xs, "") + "\" was an empty")
  }
  def `IndexedSeq("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should be an property' failed` {
    val xs = IndexedSeq("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be an empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsNotEmpty(xs, "")) + ", \"" + getFirstIsNotEmpty(xs, "") + "\" was not an empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsNotEmpty(xs, "") + "\" was not an empty")
  }
  def `IndexedSeq("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should not be an property' failed` {
    val xs = IndexedSeq("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be an (empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsEmpty(xs, "")) + ", \"" + getFirstIsEmpty(xs, "") + "\" was an empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsEmpty(xs, "") + "\" was an empty")
  }
  def `IndexedSeq("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should have property' failed` {
    val xs = IndexedSeq("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have (plength(0))
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLengthNotEqualLength(xs, 0)) + ", The length property had value " + getFirstLengthNotEqualLength(xs, 0).length + ", instead of its expected value 0, on object \"" + getFirstLengthNotEqualLength(xs, 0) + "\" (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "The length property had value " + getFirstLengthNotEqualLength(xs, 0).length + ", instead of its expected value 0, on object \"" + getFirstLengthNotEqualLength(xs, 0) + "\"")
  }
  def `IndexedSeq("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should not have property' failed` {
    val xs = IndexedSeq("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have plength(0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLengthEqual(xs, 0)) + ", The length property had its expected value 0, on object \"" + getFirstLengthEqual(xs, 0) + "\" (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "The length property had its expected value 0, on object \"" + getFirstLengthEqual(xs, 0) + "\"")
  }
  def `IndexedSeq("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should have length' failed` {
    val xs = IndexedSeq("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLengthNotEqual(xs, 0)) + ", \"" + getFirstLengthNotEqual(xs, 0) + "\" did not have length 0 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstLengthNotEqual(xs, 0) + "\" did not have length 0")
  }
  def `IndexedSeq("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should not have length' failed` {
    val xs = IndexedSeq("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLengthEqual(xs, 0)) + ", \"" + getFirstLengthEqual(xs, 0) + "\" had length 0 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstLengthEqual(xs, 0) + "\" had length 0")
  }
  def `IndexedSeq("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should have size' failed` {
    val xs = IndexedSeq("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstSizeNotEqual(xs, 0)) + ", \"" + getFirstSizeNotEqual(xs, 0) + "\" did not have size 0 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstSizeNotEqual(xs, 0) + "\" did not have size 0")
  }
  def `IndexedSeq("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should not have size' failed` {
    val xs = IndexedSeq("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstSizeEqual(xs, 0)) + ", \"" + getFirstSizeEqual(xs, 0) + "\" had size 0 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstSizeEqual(xs, 0) + "\" had size 0")
  }
  def `Vector("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should be symbol' failed` {
    val xs = Vector("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsNotEmpty(xs, "")) + ", \"" + getFirstIsNotEmpty(xs, "") + "\" was not empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsNotEmpty(xs, "") + "\" was not empty")
  }
  def `Vector("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should not be symbol' failed` {
    val xs = Vector("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsEmpty(xs, "")) + ", \"" + getFirstIsEmpty(xs, "") + "\" was empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsEmpty(xs, "") + "\" was empty")
  }
  def `Vector("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should be property' failed` {
    val xs = Vector("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be (empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsNotEmpty(xs, "")) + ", \"" + getFirstIsNotEmpty(xs, "") + "\" was not empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsNotEmpty(xs, "") + "\" was not empty")
  }
  def `Vector("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should not be property' failed` {
    val xs = Vector("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsEmpty(xs, "")) + ", \"" + getFirstIsEmpty(xs, "") + "\" was empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsEmpty(xs, "") + "\" was empty")
  }
  def `Vector("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should be a symbol' failed` {
    val xs = Vector("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be a 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsNotEmpty(xs, "")) + ", \"" + getFirstIsNotEmpty(xs, "") + "\" was not a empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsNotEmpty(xs, "") + "\" was not a empty")
  }
  def `Vector("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should not be a symbol' failed` {
    val xs = Vector("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be a ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsEmpty(xs, "")) + ", \"" + getFirstIsEmpty(xs, "") + "\" was a empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsEmpty(xs, "") + "\" was a empty")
  }
  def `Vector("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should be a property' failed` {
    val xs = Vector("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be a empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsNotEmpty(xs, "")) + ", \"" + getFirstIsNotEmpty(xs, "") + "\" was not a empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsNotEmpty(xs, "") + "\" was not a empty")
  }
  def `Vector("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should not be a property' failed` {
    val xs = Vector("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be a (empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsEmpty(xs, "")) + ", \"" + getFirstIsEmpty(xs, "") + "\" was a empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsEmpty(xs, "") + "\" was a empty")
  }
  def `Vector("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should be an symbol' failed` {
    val xs = Vector("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be an 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsNotEmpty(xs, "")) + ", \"" + getFirstIsNotEmpty(xs, "") + "\" was not an empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsNotEmpty(xs, "") + "\" was not an empty")
  }
  def `Vector("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should not be an symbol' failed` {
    val xs = Vector("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be an ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsEmpty(xs, "")) + ", \"" + getFirstIsEmpty(xs, "") + "\" was an empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsEmpty(xs, "") + "\" was an empty")
  }
  def `Vector("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should be an property' failed` {
    val xs = Vector("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be an empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsNotEmpty(xs, "")) + ", \"" + getFirstIsNotEmpty(xs, "") + "\" was not an empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsNotEmpty(xs, "") + "\" was not an empty")
  }
  def `Vector("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should not be an property' failed` {
    val xs = Vector("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be an (empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsEmpty(xs, "")) + ", \"" + getFirstIsEmpty(xs, "") + "\" was an empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsEmpty(xs, "") + "\" was an empty")
  }
  def `Vector("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should have property' failed` {
    val xs = Vector("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have (plength(0))
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLengthNotEqualLength(xs, 0)) + ", The length property had value " + getFirstLengthNotEqualLength(xs, 0).length + ", instead of its expected value 0, on object \"" + getFirstLengthNotEqualLength(xs, 0) + "\" (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "The length property had value " + getFirstLengthNotEqualLength(xs, 0).length + ", instead of its expected value 0, on object \"" + getFirstLengthNotEqualLength(xs, 0) + "\"")
  }
  def `Vector("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should not have property' failed` {
    val xs = Vector("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have plength(0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLengthEqual(xs, 0)) + ", The length property had its expected value 0, on object \"" + getFirstLengthEqual(xs, 0) + "\" (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "The length property had its expected value 0, on object \"" + getFirstLengthEqual(xs, 0) + "\"")
  }
  def `Vector("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should have length' failed` {
    val xs = Vector("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLengthNotEqual(xs, 0)) + ", \"" + getFirstLengthNotEqual(xs, 0) + "\" did not have length 0 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstLengthNotEqual(xs, 0) + "\" did not have length 0")
  }
  def `Vector("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should not have length' failed` {
    val xs = Vector("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLengthEqual(xs, 0)) + ", \"" + getFirstLengthEqual(xs, 0) + "\" had length 0 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstLengthEqual(xs, 0) + "\" had length 0")
  }
  def `Vector("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should have size' failed` {
    val xs = Vector("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstSizeNotEqual(xs, 0)) + ", \"" + getFirstSizeNotEqual(xs, 0) + "\" did not have size 0 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstSizeNotEqual(xs, 0) + "\" did not have size 0")
  }
  def `Vector("", "boom!", "") should throw TestFailedException with correct stack depth and message when 'should not have size' failed` {
    val xs = Vector("", "boom!", "")
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstSizeEqual(xs, 0)) + ", \"" + getFirstSizeEqual(xs, 0) + "\" had size 0 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstSizeEqual(xs, 0) + "\" had size 0")
  }
  def `Set("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should be symbol' failed` {
    val xs = Set("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsNotEmpty(xs, "")) + ", \"" + getFirstIsNotEmpty(xs, "") + "\" was not empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsNotEmpty(xs, "") + "\" was not empty")
  }
  def `Set("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should not be symbol' failed` {
    val xs = Set("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsEmpty(xs, "")) + ", \"" + getFirstIsEmpty(xs, "") + "\" was empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsEmpty(xs, "") + "\" was empty")
  }
  def `Set("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should be property' failed` {
    val xs = Set("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be (empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsNotEmpty(xs, "")) + ", \"" + getFirstIsNotEmpty(xs, "") + "\" was not empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsNotEmpty(xs, "") + "\" was not empty")
  }
  def `Set("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should not be property' failed` {
    val xs = Set("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsEmpty(xs, "")) + ", \"" + getFirstIsEmpty(xs, "") + "\" was empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsEmpty(xs, "") + "\" was empty")
  }
  def `Set("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should be a symbol' failed` {
    val xs = Set("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be a 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsNotEmpty(xs, "")) + ", \"" + getFirstIsNotEmpty(xs, "") + "\" was not a empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsNotEmpty(xs, "") + "\" was not a empty")
  }
  def `Set("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should not be a symbol' failed` {
    val xs = Set("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be a ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsEmpty(xs, "")) + ", \"" + getFirstIsEmpty(xs, "") + "\" was a empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsEmpty(xs, "") + "\" was a empty")
  }
  def `Set("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should be a property' failed` {
    val xs = Set("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be a empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsNotEmpty(xs, "")) + ", \"" + getFirstIsNotEmpty(xs, "") + "\" was not a empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsNotEmpty(xs, "") + "\" was not a empty")
  }
  def `Set("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should not be a property' failed` {
    val xs = Set("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be a (empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsEmpty(xs, "")) + ", \"" + getFirstIsEmpty(xs, "") + "\" was a empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsEmpty(xs, "") + "\" was a empty")
  }
  def `Set("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should be an symbol' failed` {
    val xs = Set("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be an 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsNotEmpty(xs, "")) + ", \"" + getFirstIsNotEmpty(xs, "") + "\" was not an empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsNotEmpty(xs, "") + "\" was not an empty")
  }
  def `Set("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should not be an symbol' failed` {
    val xs = Set("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be an ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsEmpty(xs, "")) + ", \"" + getFirstIsEmpty(xs, "") + "\" was an empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsEmpty(xs, "") + "\" was an empty")
  }
  def `Set("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should be an property' failed` {
    val xs = Set("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be an empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsNotEmpty(xs, "")) + ", \"" + getFirstIsNotEmpty(xs, "") + "\" was not an empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsNotEmpty(xs, "") + "\" was not an empty")
  }
  def `Set("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should not be an property' failed` {
    val xs = Set("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be an (empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsEmpty(xs, "")) + ", \"" + getFirstIsEmpty(xs, "") + "\" was an empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsEmpty(xs, "") + "\" was an empty")
  }
  def `Set("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should have property' failed` {
    val xs = Set("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have (plength(0))
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLengthNotEqualLength(xs, 0)) + ", The length property had value " + getFirstLengthNotEqualLength(xs, 0).length + ", instead of its expected value 0, on object \"" + getFirstLengthNotEqualLength(xs, 0) + "\" (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "The length property had value " + getFirstLengthNotEqualLength(xs, 0).length + ", instead of its expected value 0, on object \"" + getFirstLengthNotEqualLength(xs, 0) + "\"")
  }
  def `Set("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should not have property' failed` {
    val xs = Set("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have plength(0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLengthEqual(xs, 0)) + ", The length property had its expected value 0, on object \"" + getFirstLengthEqual(xs, 0) + "\" (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "The length property had its expected value 0, on object \"" + getFirstLengthEqual(xs, 0) + "\"")
  }
  def `Set("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should have length' failed` {
    val xs = Set("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLengthNotEqual(xs, 0)) + ", \"" + getFirstLengthNotEqual(xs, 0) + "\" did not have length 0 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstLengthNotEqual(xs, 0) + "\" did not have length 0")
  }
  def `Set("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should not have length' failed` {
    val xs = Set("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLengthEqual(xs, 0)) + ", \"" + getFirstLengthEqual(xs, 0) + "\" had length 0 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstLengthEqual(xs, 0) + "\" had length 0")
  }
  def `Set("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should have size' failed` {
    val xs = Set("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstSizeNotEqual(xs, 0)) + ", \"" + getFirstSizeNotEqual(xs, 0) + "\" did not have size 0 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstSizeNotEqual(xs, 0) + "\" did not have size 0")
  }
  def `Set("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should not have size' failed` {
    val xs = Set("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstSizeEqual(xs, 0)) + ", \"" + getFirstSizeEqual(xs, 0) + "\" had size 0 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstSizeEqual(xs, 0) + "\" had size 0")
  }
  def `List("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should be symbol' failed` {
    val xs = List("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsNotEmpty(xs, "")) + ", \"" + getFirstIsNotEmpty(xs, "") + "\" was not empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsNotEmpty(xs, "") + "\" was not empty")
  }
  def `List("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should not be symbol' failed` {
    val xs = List("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsEmpty(xs, "")) + ", \"" + getFirstIsEmpty(xs, "") + "\" was empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsEmpty(xs, "") + "\" was empty")
  }
  def `List("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should be property' failed` {
    val xs = List("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be (empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsNotEmpty(xs, "")) + ", \"" + getFirstIsNotEmpty(xs, "") + "\" was not empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsNotEmpty(xs, "") + "\" was not empty")
  }
  def `List("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should not be property' failed` {
    val xs = List("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsEmpty(xs, "")) + ", \"" + getFirstIsEmpty(xs, "") + "\" was empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsEmpty(xs, "") + "\" was empty")
  }
  def `List("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should be a symbol' failed` {
    val xs = List("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be a 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsNotEmpty(xs, "")) + ", \"" + getFirstIsNotEmpty(xs, "") + "\" was not a empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsNotEmpty(xs, "") + "\" was not a empty")
  }
  def `List("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should not be a symbol' failed` {
    val xs = List("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be a ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsEmpty(xs, "")) + ", \"" + getFirstIsEmpty(xs, "") + "\" was a empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsEmpty(xs, "") + "\" was a empty")
  }
  def `List("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should be a property' failed` {
    val xs = List("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be a empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsNotEmpty(xs, "")) + ", \"" + getFirstIsNotEmpty(xs, "") + "\" was not a empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsNotEmpty(xs, "") + "\" was not a empty")
  }
  def `List("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should not be a property' failed` {
    val xs = List("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be a (empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsEmpty(xs, "")) + ", \"" + getFirstIsEmpty(xs, "") + "\" was a empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsEmpty(xs, "") + "\" was a empty")
  }
  def `List("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should be an symbol' failed` {
    val xs = List("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be an 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsNotEmpty(xs, "")) + ", \"" + getFirstIsNotEmpty(xs, "") + "\" was not an empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsNotEmpty(xs, "") + "\" was not an empty")
  }
  def `List("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should not be an symbol' failed` {
    val xs = List("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be an ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsEmpty(xs, "")) + ", \"" + getFirstIsEmpty(xs, "") + "\" was an empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsEmpty(xs, "") + "\" was an empty")
  }
  def `List("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should be an property' failed` {
    val xs = List("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be an empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsNotEmpty(xs, "")) + ", \"" + getFirstIsNotEmpty(xs, "") + "\" was not an empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsNotEmpty(xs, "") + "\" was not an empty")
  }
  def `List("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should not be an property' failed` {
    val xs = List("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be an (empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsEmpty(xs, "")) + ", \"" + getFirstIsEmpty(xs, "") + "\" was an empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsEmpty(xs, "") + "\" was an empty")
  }
  def `List("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should have property' failed` {
    val xs = List("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have (plength(0))
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLengthNotEqualLength(xs, 0)) + ", The length property had value " + getFirstLengthNotEqualLength(xs, 0).length + ", instead of its expected value 0, on object \"" + getFirstLengthNotEqualLength(xs, 0) + "\" (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "The length property had value " + getFirstLengthNotEqualLength(xs, 0).length + ", instead of its expected value 0, on object \"" + getFirstLengthNotEqualLength(xs, 0) + "\"")
  }
  def `List("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should not have property' failed` {
    val xs = List("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have plength(0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLengthEqual(xs, 0)) + ", The length property had its expected value 0, on object \"" + getFirstLengthEqual(xs, 0) + "\" (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "The length property had its expected value 0, on object \"" + getFirstLengthEqual(xs, 0) + "\"")
  }
  def `List("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should have length' failed` {
    val xs = List("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLengthNotEqual(xs, 0)) + ", \"" + getFirstLengthNotEqual(xs, 0) + "\" did not have length 0 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstLengthNotEqual(xs, 0) + "\" did not have length 0")
  }
  def `List("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should not have length' failed` {
    val xs = List("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLengthEqual(xs, 0)) + ", \"" + getFirstLengthEqual(xs, 0) + "\" had length 0 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstLengthEqual(xs, 0) + "\" had length 0")
  }
  def `List("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should have size' failed` {
    val xs = List("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstSizeNotEqual(xs, 0)) + ", \"" + getFirstSizeNotEqual(xs, 0) + "\" did not have size 0 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstSizeNotEqual(xs, 0) + "\" did not have size 0")
  }
  def `List("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should not have size' failed` {
    val xs = List("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstSizeEqual(xs, 0)) + ", \"" + getFirstSizeEqual(xs, 0) + "\" had size 0 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstSizeEqual(xs, 0) + "\" had size 0")
  }
  def `Seq("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should be symbol' failed` {
    val xs = Seq("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsNotEmpty(xs, "")) + ", \"" + getFirstIsNotEmpty(xs, "") + "\" was not empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsNotEmpty(xs, "") + "\" was not empty")
  }
  def `Seq("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should not be symbol' failed` {
    val xs = Seq("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsEmpty(xs, "")) + ", \"" + getFirstIsEmpty(xs, "") + "\" was empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsEmpty(xs, "") + "\" was empty")
  }
  def `Seq("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should be property' failed` {
    val xs = Seq("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be (empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsNotEmpty(xs, "")) + ", \"" + getFirstIsNotEmpty(xs, "") + "\" was not empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsNotEmpty(xs, "") + "\" was not empty")
  }
  def `Seq("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should not be property' failed` {
    val xs = Seq("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsEmpty(xs, "")) + ", \"" + getFirstIsEmpty(xs, "") + "\" was empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsEmpty(xs, "") + "\" was empty")
  }
  def `Seq("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should be a symbol' failed` {
    val xs = Seq("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be a 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsNotEmpty(xs, "")) + ", \"" + getFirstIsNotEmpty(xs, "") + "\" was not a empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsNotEmpty(xs, "") + "\" was not a empty")
  }
  def `Seq("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should not be a symbol' failed` {
    val xs = Seq("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be a ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsEmpty(xs, "")) + ", \"" + getFirstIsEmpty(xs, "") + "\" was a empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsEmpty(xs, "") + "\" was a empty")
  }
  def `Seq("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should be a property' failed` {
    val xs = Seq("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be a empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsNotEmpty(xs, "")) + ", \"" + getFirstIsNotEmpty(xs, "") + "\" was not a empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsNotEmpty(xs, "") + "\" was not a empty")
  }
  def `Seq("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should not be a property' failed` {
    val xs = Seq("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be a (empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsEmpty(xs, "")) + ", \"" + getFirstIsEmpty(xs, "") + "\" was a empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsEmpty(xs, "") + "\" was a empty")
  }
  def `Seq("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should be an symbol' failed` {
    val xs = Seq("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be an 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsNotEmpty(xs, "")) + ", \"" + getFirstIsNotEmpty(xs, "") + "\" was not an empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsNotEmpty(xs, "") + "\" was not an empty")
  }
  def `Seq("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should not be an symbol' failed` {
    val xs = Seq("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be an ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsEmpty(xs, "")) + ", \"" + getFirstIsEmpty(xs, "") + "\" was an empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsEmpty(xs, "") + "\" was an empty")
  }
  def `Seq("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should be an property' failed` {
    val xs = Seq("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be an empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsNotEmpty(xs, "")) + ", \"" + getFirstIsNotEmpty(xs, "") + "\" was not an empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsNotEmpty(xs, "") + "\" was not an empty")
  }
  def `Seq("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should not be an property' failed` {
    val xs = Seq("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be an (empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsEmpty(xs, "")) + ", \"" + getFirstIsEmpty(xs, "") + "\" was an empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsEmpty(xs, "") + "\" was an empty")
  }
  def `Seq("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should have property' failed` {
    val xs = Seq("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have (plength(0))
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLengthNotEqualLength(xs, 0)) + ", The length property had value " + getFirstLengthNotEqualLength(xs, 0).length + ", instead of its expected value 0, on object \"" + getFirstLengthNotEqualLength(xs, 0) + "\" (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "The length property had value " + getFirstLengthNotEqualLength(xs, 0).length + ", instead of its expected value 0, on object \"" + getFirstLengthNotEqualLength(xs, 0) + "\"")
  }
  def `Seq("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should not have property' failed` {
    val xs = Seq("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have plength(0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLengthEqual(xs, 0)) + ", The length property had its expected value 0, on object \"" + getFirstLengthEqual(xs, 0) + "\" (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "The length property had its expected value 0, on object \"" + getFirstLengthEqual(xs, 0) + "\"")
  }
  def `Seq("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should have length' failed` {
    val xs = Seq("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLengthNotEqual(xs, 0)) + ", \"" + getFirstLengthNotEqual(xs, 0) + "\" did not have length 0 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstLengthNotEqual(xs, 0) + "\" did not have length 0")
  }
  def `Seq("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should not have length' failed` {
    val xs = Seq("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLengthEqual(xs, 0)) + ", \"" + getFirstLengthEqual(xs, 0) + "\" had length 0 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstLengthEqual(xs, 0) + "\" had length 0")
  }
  def `Seq("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should have size' failed` {
    val xs = Seq("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstSizeNotEqual(xs, 0)) + ", \"" + getFirstSizeNotEqual(xs, 0) + "\" did not have size 0 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstSizeNotEqual(xs, 0) + "\" did not have size 0")
  }
  def `Seq("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should not have size' failed` {
    val xs = Seq("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstSizeEqual(xs, 0)) + ", \"" + getFirstSizeEqual(xs, 0) + "\" had size 0 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstSizeEqual(xs, 0) + "\" had size 0")
  }
  def `IndexedSeq("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should be symbol' failed` {
    val xs = IndexedSeq("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsNotEmpty(xs, "")) + ", \"" + getFirstIsNotEmpty(xs, "") + "\" was not empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsNotEmpty(xs, "") + "\" was not empty")
  }
  def `IndexedSeq("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should not be symbol' failed` {
    val xs = IndexedSeq("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsEmpty(xs, "")) + ", \"" + getFirstIsEmpty(xs, "") + "\" was empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsEmpty(xs, "") + "\" was empty")
  }
  def `IndexedSeq("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should be property' failed` {
    val xs = IndexedSeq("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be (empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsNotEmpty(xs, "")) + ", \"" + getFirstIsNotEmpty(xs, "") + "\" was not empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsNotEmpty(xs, "") + "\" was not empty")
  }
  def `IndexedSeq("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should not be property' failed` {
    val xs = IndexedSeq("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsEmpty(xs, "")) + ", \"" + getFirstIsEmpty(xs, "") + "\" was empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsEmpty(xs, "") + "\" was empty")
  }
  def `IndexedSeq("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should be a symbol' failed` {
    val xs = IndexedSeq("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be a 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsNotEmpty(xs, "")) + ", \"" + getFirstIsNotEmpty(xs, "") + "\" was not a empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsNotEmpty(xs, "") + "\" was not a empty")
  }
  def `IndexedSeq("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should not be a symbol' failed` {
    val xs = IndexedSeq("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be a ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsEmpty(xs, "")) + ", \"" + getFirstIsEmpty(xs, "") + "\" was a empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsEmpty(xs, "") + "\" was a empty")
  }
  def `IndexedSeq("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should be a property' failed` {
    val xs = IndexedSeq("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be a empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsNotEmpty(xs, "")) + ", \"" + getFirstIsNotEmpty(xs, "") + "\" was not a empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsNotEmpty(xs, "") + "\" was not a empty")
  }
  def `IndexedSeq("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should not be a property' failed` {
    val xs = IndexedSeq("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be a (empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsEmpty(xs, "")) + ", \"" + getFirstIsEmpty(xs, "") + "\" was a empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsEmpty(xs, "") + "\" was a empty")
  }
  def `IndexedSeq("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should be an symbol' failed` {
    val xs = IndexedSeq("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be an 'empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsNotEmpty(xs, "")) + ", \"" + getFirstIsNotEmpty(xs, "") + "\" was not an empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsNotEmpty(xs, "") + "\" was not an empty")
  }
  def `IndexedSeq("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should not be an symbol' failed` {
    val xs = IndexedSeq("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be an ('empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsEmpty(xs, "")) + ", \"" + getFirstIsEmpty(xs, "") + "\" was an empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsEmpty(xs, "") + "\" was an empty")
  }
  def `IndexedSeq("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should be an property' failed` {
    val xs = IndexedSeq("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should be an empty
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsNotEmpty(xs, "")) + ", \"" + getFirstIsNotEmpty(xs, "") + "\" was not an empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsNotEmpty(xs, "") + "\" was not an empty")
  }
  def `IndexedSeq("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should not be an property' failed` {
    val xs = IndexedSeq("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not be an (empty)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstIsEmpty(xs, "")) + ", \"" + getFirstIsEmpty(xs, "") + "\" was an empty (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstIsEmpty(xs, "") + "\" was an empty")
  }
  def `IndexedSeq("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should have property' failed` {
    val xs = IndexedSeq("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have (plength(0))
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLengthNotEqualLength(xs, 0)) + ", The length property had value " + getFirstLengthNotEqualLength(xs, 0).length + ", instead of its expected value 0, on object \"" + getFirstLengthNotEqualLength(xs, 0) + "\" (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "The length property had value " + getFirstLengthNotEqualLength(xs, 0).length + ", instead of its expected value 0, on object \"" + getFirstLengthNotEqualLength(xs, 0) + "\"")
  }
  def `IndexedSeq("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should not have property' failed` {
    val xs = IndexedSeq("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have plength(0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLengthEqual(xs, 0)) + ", The length property had its expected value 0, on object \"" + getFirstLengthEqual(xs, 0) + "\" (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "The length property had its expected value 0, on object \"" + getFirstLengthEqual(xs, 0) + "\"")
  }
  def `IndexedSeq("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should have length' failed` {
    val xs = IndexedSeq("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have length 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLengthNotEqual(xs, 0)) + ", \"" + getFirstLengthNotEqual(xs, 0) + "\" did not have length 0 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstLengthNotEqual(xs, 0) + "\" did not have length 0")
  }
  def `IndexedSeq("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should not have length' failed` {
    val xs = IndexedSeq("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have length (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstLengthEqual(xs, 0)) + ", \"" + getFirstLengthEqual(xs, 0) + "\" had length 0 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstLengthEqual(xs, 0) + "\" had length 0")
  }
  def `IndexedSeq("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should have size' failed` {
    val xs = IndexedSeq("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should have size 0
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstSizeNotEqual(xs, 0)) + ", \"" + getFirstSizeNotEqual(xs, 0) + "\" did not have size 0 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstSizeNotEqual(xs, 0) + "\" did not have size 0")
  }
  def `IndexedSeq("", "boom!", "").par should throw TestFailedException with correct stack depth and message when 'should not have size' failed` {
    val xs = IndexedSeq("", "boom!", "").par
    val e = intercept[exceptions.TestFailedException] {
      all(xs) should not have size (0)
    }
    val assertLineNumber = thisLineNumber - 2
    checkErrorAndCause(e, assertLineNumber, "InspectorShorthandsForAllFailedSpec0.scala", "'all' inspection failed, because: \n" + 
  "  at index " + getIndex(xs, getFirstSizeEqual(xs, 0)) + ", \"" + getFirstSizeEqual(xs, 0) + "\" had size 0 (InspectorShorthandsForAllFailedSpec0.scala:" + assertLineNumber + ") \n" + 
  "in " + xs, "\"" + getFirstSizeEqual(xs, 0) + "\" had size 0")
  }
}
